<?php
/******************************************************************
Author: Chris Baldelomar
URL: http://webplantmedia.com

This is where you can place important function, define 
you constants, load any libraries you may want to include
in your theme. You should also drop your custom functions that you
will call from any of the pages in Wordpress' template heirachy.
You should also include any helper functions that support your
custom function.
http://codex.wordpress.org/Template_Hierarchy
******************************************************************/

/* 
 * The Options Framework Theme has all the code included to 
 * build a out a full featured options panel.
 * http://wptheming.com/options-framework-theme/
 */
if ( !function_exists( 'optionsframework_init' ) ) {
	define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/inc/theme-options/' );
	require_once dirname( __FILE__ ) . '/inc/theme-options/options-framework.php';
}

/**
 * webpm_init 
 *
 * Define important constants for our theme
 * 
 * @access public
 * @return void
 */
function webpm_init() {
    global $content_width;

    // fetch upload folder path
    $dir = wp_upload_dir();

    // jetpack gallery uses this
    if ( ! isset( $content_width ) )
        $content_width = 1020;

    // get sidebar position
    $position = of_get_option('sidebar', 'right');

    // show sidebar on blog
    $show_sidebar_on_blog = (bool) of_get_option('show_sidebar_on_blog', 1);

    define( 'WEBPM_VERSION', '2.1' );
    define( 'CONTENT_LAYOUT', 'layout1' );
    define( 'SIDEBAR_POSITION', $position );
    define( 'HEADER_WIDTH', 'span12 header-width' );
    define( 'MAIN_WIDTH', 'span8 main-width' );
    define( 'FOOTER_WIDTH', 'span12 footer-width' );
    define( 'FULL_WIDTH', 'span12 full-width' );
    define( 'SIDEBAR_WIDTH', 'span4 sidebar-width' );
    define( 'SHOW_SIDEBAR_ON_BLOG', $show_sidebar_on_blog );
    define( 'MAX_IMAGE_LENGTH', 1100 );
    define( 'HEADER_IMAGE_WIDTH', 1060 );
    define( 'HEADER_IMAGE_HEIGHT', 260 );
    define( 'CAROUSEL_IMAGE_WIDTH', 1060 );
    define( 'CAROUSEL_IMAGE_HEIGHT', 500 );
    define( 'HOME_URL', home_url() );
    define( 'PAGE_FOR_POSTS', get_option('page_for_posts') );
    define( 'PAGE_ON_FRONT', get_option('page_on_front') );
    define( 'THEME_PATH', get_stylesheet_directory() );
    define( 'THEME_URI', get_stylesheet_directory_uri() );
    define( 'UPLOAD_PATH', $dir['basedir'] );
    define( 'THEME_NAME', get_stylesheet() );
}

// run init
webpm_init();

/**
 * This function accepts one parameter, $stylesheet, which 
 * should be the name and path of the stylesheet relative to 
 * the theme root. It also accepts an array of stylesheets. If 
 * the parameter is not provided, it will default to 'editor-style.css'.
 * http://codex.wordpress.org/Function_Reference/add_editor_style 
 */
add_editor_style('css/editor-style.css');

/**
 * Calls inc/admin.php
 *
 * - removing some default WordPress dashboard widgets
 * - an example custom dashboard widget
 * - adding custom login css
 * - changing text in footer of admin
 */
require_once('inc/admin.php');

/**
 * Calls inc/bones.php
 *
 * Loads all hooks, action, and filter for this theme.
 *
 */
require_once('inc/bones.php');

/**
 * Call widget specific functions 
 */
require_once('inc/bootstrap-widgets.php');

/**
 * Call shortcodes to display bootstrap functions
 * http://twitter.github.com/bootstrap/
 */
require_once('inc/bootstrap-shortcodes.php');

/**
 * Calls inc/custom-post-type.php 
 *
 * This file enables and configures custom post types.
 * http://codex.wordpress.org/Function_Reference/register_post_type
 */
require_once('inc/custom-post-type.php');

/**
 * Calls inc/metaboxes/init.php
 *
 * This file loads metaboxes library
 * https://github.com/jaredatch/Custom-Metaboxes-and-Fields-for-WordPress 
 */
require_once('inc/metaboxes/init.php');

/**
 * Calls translation/translation.php
 *
 * - adding support for other languages
*/
// require_once('translation/translation.php'); // this comes turned off by default

/**
 * bones_main_nav 
 *
 * The main menu
 *
 * @access public
 * @return void
 */
function bones_main_nav() {
    $menu_class = '';
    if ( $menu_align = of_get_option( 'menu_align' ) )
        if ( $menu_align == 'right' )
            $menu_class = ' pull-right';

    // display the wp3 menu if available
    wp_nav_menu(array(
        'container_class' => 'nav-collapse collapse',
        'menu_class' => 'nav'.$menu_class,
        'menu_id' => 'nav-main',
        'menu' => 'The Main Menu',                      // nav name
        'theme_location' => 'main-nav',                 // where it's located in the theme
        'before' => '',                                 // before the menu
        'after' => '',                                  // after the menu
        'link_before' => '',                            // before each link
        'link_after' => '',                             // after each link
        'depth' => 0,                                   // limit the depth of the nav
        'fallback_cb' => 'bones_main_nav_fallback'      // fallback function
    ));
}

/**
 * bones_footer_links 
 *
 * The footer menu (should you choose to use one)
 *
 * @access public
 * @return void
 */
function bones_footer_links() {
    // display the wp3 menu if available
    wp_nav_menu(array(
        'container' => '',                                  // remove nav container
        'container_class' => 'footer-links clearfix',       // class of container (should you choose to use it)
        'menu' => 'Footer Links',                           // nav name
        'menu_class' => 'nav footer-nav clearfix',          // adding custom nav class
        'theme_location' => 'footer-links',                 // where it's located in the theme
        'before' => '',                                     // before the menu
        'after' => '',                                      // after the menu
        'link_before' => '',                                // before each link
        'link_after' => '',                                 // after each link
        'depth' => 0,                                       // limit the depth of the nav
        'fallback_cb' => 'bootstrap_footer_links_fallback'  // fallback function
    ));
}

/**
 * bones_main_nav_fallback 
 *
 * This is the fallback for header menu
 *
 * @access public
 * @return void
 */
function bones_main_nav_fallback() {
    $menu_class = '';
    if ( $menu_align = of_get_option( 'menu_align' ) )
        if ( $menu_align == 'right' )
            $menu_class = ' pull-right';

    $show_home = (bool) of_get_option( 'show_home', 1 );

    bootstrap_page_menu( array(
        'show_home' => $show_home,
        'sort_column'=> 'menu_order',
        'include'     => '',
        'ul_class' => 'nav'.$menu_class,
        'menu_class' => 'nav-collapse collapse',
        'exclude'     => '',
        'echo'        => true,
        'link_before' => '',
        'link_after' => '',
    ) );
}

/**
 * bones_footer_links_fallback 
 *
 * this is the fallback for footer menu
 *
 * @access public
 * @return void
 */
function bootstrap_footer_links_fallback() {
    /* you can put a default here if you like */
}

/**
 * Display or retrieve list of pages with optional home link.
 *
 * The arguments are listed below and part of the arguments are for {@link
 * wp_list_pages()} function. Check that function for more info on those
 * arguments.
 *
 * <ul>
 * <li><strong>sort_column</strong> - How to sort the list of pages. Defaults
 * to page title. Use column for posts table.</li>
 * <li><strong>menu_class</strong> - Class to use for the div ID which contains
 * the page list. Defaults to 'menu'.</li>
 * <li><strong>echo</strong> - Whether to echo list or return it. Defaults to
 * echo.</li>
 * <li><strong>link_before</strong> - Text before show_home argument text.</li>
 * <li><strong>link_after</strong> - Text after show_home argument text.</li>
 * <li><strong>show_home</strong> - If you set this argument, then it will
 * display the link to the home page. The show_home argument really just needs
 * to be set to the value of the text of the link.</li>
 * </ul>
 *
 * @since 2.7.0
 *
 * @param array|string $args
 * @return string html menu
 */
function bootstrap_page_menu( $args = array() ) {
	$defaults = array('sort_column' => 'menu_order, post_title', 'menu_class' => 'menu', 'ul_class' => 'nav', 'echo' => true, 'link_before' => '', 'link_after' => '');
	$args = wp_parse_args( $args, $defaults );
	$args = apply_filters( 'wp_page_menu_args', $args );

	$menu = '';

	$list_args = $args;

	// Show Home in the menu
	if ( ! empty($args['show_home']) ) {
		if ( true === $args['show_home'] || '1' === $args['show_home'] || 1 === $args['show_home'] )
			$text = __('Home');
		else
			$text = $args['show_home'];
		$class = '';
		if ( is_front_page() && !is_paged() )
			$class = 'class="current_page_item"';
		$menu .= '<li ' . $class . '><a href="' . home_url( '/' ) . '" title="' . esc_attr($text) . '">' . $args['link_before'] . $text . $args['link_after'] . '</a></li>';
		// If the front page is a page, add it to the exclude list
		if (get_option('show_on_front') == 'page') {
			if ( !empty( $list_args['exclude'] ) ) {
				$list_args['exclude'] .= ',';
			} else {
				$list_args['exclude'] = '';
			}
			$list_args['exclude'] .= get_option('page_on_front');
		}
	}

	$list_args['echo'] = false;
	$list_args['title_li'] = '';
	$menu .= str_replace( array( "\r", "\n", "\t" ), '', wp_list_pages($list_args) );

	if ( $menu )
		$menu = '<ul class="' . esc_attr($args['ul_class']) . '">' . $menu . '</ul>';

	$menu = '<div class="' . esc_attr($args['menu_class']) . '">' . $menu . "</div>\n";
	$menu = apply_filters( 'wp_page_menu', $menu, $args );
	if ( $args['echo'] )
		echo $menu;
	else
		return $menu;
}

/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own twentytwelve_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since Twenty Twelve 1.0
 */
function webpm_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
		// Display trackbacks differently than normal comments.
	?>
	<li <?php comment_class(); ?> id="comment-<?php comment_ID(); ?>">
		<p><?php _e( 'Pingback:', 'webpm' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( '(Edit)', 'webpm' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
		// Proceed with normal comments.
		global $post;
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
        <div class="avatar-wrapper pull-left">
            <?php echo get_avatar( $comment, 64 ); ?>
        </div>
		<article id="comment-<?php comment_ID(); ?>" class="comment media-body">
			<header class="comment-meta comment-author vcard">
                <h5>
				<?php
					printf( '<cite class="fn">%1$s %2$s</cite>',
						get_comment_author_link(),
						// If current post author is also comment author, make it known visually.
						( $comment->user_id === $post->post_author ) ? '<span> ' . __( 'Post author', 'webpm' ) . ' </span>' : ''
					);
					printf( '<a href="%1$s"><time datetime="%2$s">%3$s</time></a>',
						esc_url( get_comment_link( $comment->comment_ID ) ),
						get_comment_time( 'c' ),
						/* translators: 1: date, 2: time */
						sprintf( __( '%1$s at %2$s', 'webpm' ), get_comment_date(), get_comment_time() )
					);
				?>
                </h5>
			</header><!-- .comment-meta -->

			<?php if ( '0' == $comment->comment_approved ) : ?>
				<p class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'webpm' ); ?></p>
			<?php endif; ?>

			<section class="comment-content comment">
				<?php comment_text(); ?>
                <p>
                    <?php edit_comment_link( __( 'Edit', 'webpm' ), '', '' ); ?>
                    <?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply', 'webpm' ), 'after' => '', 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
                </p>
			</section><!-- .comment-content -->

			<div class="reply">
			</div><!-- .reply -->
		</article><!-- #comment-## -->
	<?php
		break;
	endswitch; // end comment_type check
}

/**
 * Retrieve paginated link for archive post pages.
 *
 * Technically, the function can be used to create paginated link list for any
 * area. The 'base' argument is used to reference the url, which will be used to
 * create the paginated links. The 'format' argument is then used for replacing
 * the page number. It is however, most likely and by default, to be used on the
 * archive post pages.
 *
 * The 'type' argument controls format of the returned value. The default is
 * 'plain', which is just a string with the links separated by a newline
 * character. The other possible values are either 'array' or 'list'. The
 * 'array' value will return an array of the paginated link list to offer full
 * control of display. The 'list' value will place all of the paginated links in
 * an unordered HTML list.
 *
 * The 'total' argument is the total amount of pages and is an integer. The
 * 'current' argument is the current page number and is also an integer.
 *
 * An example of the 'base' argument is "http://example.com/all_posts.php%_%"
 * and the '%_%' is required. The '%_%' will be replaced by the contents of in
 * the 'format' argument. An example for the 'format' argument is "?page=%#%"
 * and the '%#%' is also required. The '%#%' will be replaced with the page
 * number.
 *
 * You can include the previous and next links in the list by setting the
 * 'prev_next' argument to true, which it is by default. You can set the
 * previous text, by using the 'prev_text' argument. You can set the next text
 * by setting the 'next_text' argument.
 *
 * If the 'show_all' argument is set to true, then it will show all of the pages
 * instead of a short list of the pages near the current page. By default, the
 * 'show_all' is set to false and controlled by the 'end_size' and 'mid_size'
 * arguments. The 'end_size' argument is how many numbers on either the start
 * and the end list edges, by default is 1. The 'mid_size' argument is how many
 * numbers to either side of current page, but not including current page.
 *
 * It is possible to add query vars to the link by using the 'add_args' argument
 * and see {@link add_query_arg()} for more information.
 *
 * @since 2.1.0
 *
 * @param string|array $args Optional. Override defaults.
 * @return array|string String of page links or array of page links.
 */
function webpm_paginate_links( $args = '' ) {
	$defaults = array(
		'base' => '%_%', // http://example.com/all_posts.php%_% : %_% is replaced by format (below)
		'format' => '?page=%#%', // ?page=%#% : %#% is replaced by the page number
		'total' => 1,
		'current' => 0,
		'show_all' => false,
		'prev_next' => true,
		'prev_text' => __('&laquo;'),
		'next_text' => __('&raquo;'),
		'end_size' => 1,
		'mid_size' => 2,
		'type' => 'plain',
		'add_args' => false, // array of query args to add
		'add_fragment' => ''
	);

	$args = wp_parse_args( $args, $defaults );
	extract($args, EXTR_SKIP);

	// Who knows what else people pass in $args
	$total = (int) $total;
	if ( $total < 2 )
		return;
	$current  = (int) $current;
	$end_size = 0  < (int) $end_size ? (int) $end_size : 1; // Out of bounds?  Make it the default.
	$mid_size = 0 <= (int) $mid_size ? (int) $mid_size : 2;
	$add_args = is_array($add_args) ? $add_args : false;
	$r = '';
	$page_links = array();
	$n = 0;
	$dots = false;

	if ( $prev_next && $current && 1 < $current ) :
		$link = str_replace('%_%', 2 == $current ? '' : $format, $base);
		$link = str_replace('%#%', $current - 1, $link);
		if ( $add_args )
			$link = add_query_arg( $add_args, $link );
		$link .= $add_fragment;
		$page_links[] = '<li><a class="prev page-numbers" href="' . esc_url( apply_filters( 'paginate_links', $link ) ) . '">' . $prev_text . '</a></li>';
	endif;
	for ( $n = 1; $n <= $total; $n++ ) :
		$n_display = number_format_i18n($n);
		if ( $n == $current ) :
			$page_links[] = "<li class='page-numbers active'><a>$n_display</a></li>";
			$dots = true;
		else :
			if ( $show_all || ( $n <= $end_size || ( $current && $n >= $current - $mid_size && $n <= $current + $mid_size ) || $n > $total - $end_size ) ) :
				$link = str_replace('%_%', 1 == $n ? '' : $format, $base);
				$link = str_replace('%#%', $n, $link);
				if ( $add_args )
					$link = add_query_arg( $add_args, $link );
				$link .= $add_fragment;
				$page_links[] = "<li><a class='page-numbers' href='" . esc_url( apply_filters( 'paginate_links', $link ) ) . "'>$n_display</a></li>";
				$dots = true;
			elseif ( $dots && !$show_all ) :
				$page_links[] = '<li class="page-numbers disabled"><a>' . __( '&hellip;' ) . '</a></li>';
				$dots = false;
			endif;
		endif;
	endfor;
	if ( $prev_next && $current && ( $current < $total || -1 == $total ) ) :
		$link = str_replace('%_%', $format, $base);
		$link = str_replace('%#%', $current + 1, $link);
		if ( $add_args )
			$link = add_query_arg( $add_args, $link );
		$link .= $add_fragment;
		$page_links[] = '<li><a class="next page-numbers" href="' . esc_url( apply_filters( 'paginate_links', $link ) ) . '">' . $next_text . '</a></li>';
	endif;
	switch ( $type ) :
		case 'array' :
			return $page_links;
			break;
		case 'list' :
			$r .= "<ul class='page-numbers'>";
			$r .= join("", $page_links);
			$r .= "</ul>\n";
			break;
		default :
			$r = join("\n", $page_links);
			break;
	endswitch;
	return $r;
}

/**
 * bones_related_posts 
 * 
 * Related Posts Function (call using bones_related_posts(); )
 * 
 * @access public
 * @return void
 */
function bones_related_posts() {
    echo '<ul id="bones-related-posts">';
    global $post;
    $tags = wp_get_post_tags($post->ID);
    if($tags) {
        foreach($tags as $tag) { $tag_arr .= $tag->slug . ','; }
        $args = array(
            'tag' => $tag_arr,
            'numberposts' => 5, /* you can change this to show more */
            'post__not_in' => array($post->ID)
        );
        $related_posts = get_posts($args);
        if($related_posts) {
            foreach ($related_posts as $post) : setup_postdata($post); ?>
                <li class="related_post"><a class="entry-unrelated" href="<?php the_permalink() ?>" title="<?php the_title_attribute(); ?>"><?php the_title(); ?></a></li>
            <?php endforeach; }
        else { ?>
            <?php echo '<li class="no_related_post">No Related Posts Yet!</li>'; ?>
        <?php }
    }
    wp_reset_query();
    echo '</ul>';
}

/**
 * bones_page_navi 
 *
 * Numeric Page Navi (built into the theme by default)
 *
 * @param string $before 
 * @param string $after 
 * @access public
 * @return void
 */
function bones_page_navi($before = '', $after = '') {
    global $wpdb, $wp_query;
    $request = $wp_query->request;
    $posts_per_page = intval(get_query_var('posts_per_page'));
    $paged = intval(get_query_var('paged'));
    $numposts = $wp_query->found_posts;
    $max_page = $wp_query->max_num_pages;
    if ( $numposts <= $posts_per_page ) { return; }
    if(empty($paged) || $paged == 0) {
        $paged = 1;
    }
    $pages_to_show = 7;
    $pages_to_show_minus_1 = $pages_to_show-1;
    $half_page_start = floor($pages_to_show_minus_1/2);
    $half_page_end = ceil($pages_to_show_minus_1/2);
    $start_page = $paged - $half_page_start;
    if($start_page <= 0) {
        $start_page = 1;
    }
    $end_page = $paged + $half_page_end;
    if(($end_page - $start_page) != $pages_to_show_minus_1) {
        $end_page = $start_page + $pages_to_show_minus_1;
    }
    if($end_page > $max_page) {
        $start_page = $max_page - $pages_to_show_minus_1;
        $end_page = $max_page;
    }
    if($start_page <= 0) {
        $start_page = 1;
    }
    echo $before.'<nav class="page-navigation"><ol class="bones_page_navi clearfix">'."";
    if ($start_page >= 2 && $pages_to_show < $max_page) {
        $first_page_text = "First";
        echo '<li class="bpn-first-page-link"><a href="'.get_pagenum_link().'" title="'.$first_page_text.'">'.$first_page_text.'</a></li>';
    }
    echo '<li class="bpn-prev-link">';
    previous_posts_link('<<');
    echo '</li>';
    for($i = $start_page; $i  <= $end_page; $i++) {
        if($i == $paged) {
            echo '<li class="bpn-current">'.$i.'</li>';
        } else {
            echo '<li><a href="'.get_pagenum_link($i).'">'.$i.'</a></li>';
        }
    }
    echo '<li class="bpn-next-link">';
    next_posts_link('>>');
    echo '</li>';
    if ($end_page < $max_page) {
        $last_page_text = "Last";
        echo '<li class="bpn-last-page-link"><a href="'.get_pagenum_link($max_page).'" title="'.$last_page_text.'">'.$last_page_text.'</a></li>';
    }
    echo '</ol></nav>'.$after."";
}

/**
 * the_signature 
 * 
 * @access public
 * @return void
 */
function the_signature() {
    if ( $signature = of_get_option('post_signature') ) {
        echo get_the_signature();
    }
}

/**
 * get_the_signature 
 * 
 * @access public
 * @return void
 */
function get_the_signature() {
    if ( $signature = of_get_option('post_signature') ) {
        return '<p class="post-signature"><img src="'.$signature.'" /></p>';
    }

    return '';
}

/**
 * the_byline 
 * 
 * @access public
 * @return void
 */
function the_byline() {
    ?>

    <p class="byline vcard">

        <?php _e('Posted', 'webpm'); ?> <?php _e('by', 'webpm'); ?> <span class="author"><?php the_author_posts_link(); ?></span> <span class="amp">&</span> <?php _e('filed under', 'webpm'); ?> <?php the_category(', '); ?>. This post has <a href="<?php comments_link(); ?>"> <?php comments_number( 'no comments yet', 'one comment', '% comments' ); ?>.</a>			

    </p>

    <?php
}

function the_share_buttons() {
    global $post;
    ?>

    <p class="share-buttons">

        <?php if ( $image_src = get_option( 'webpm_sharing_pinterest_button', THEME_URI.'/img/share-buttons/pinterest.png' ) ) : ?>

            <?php $src = ''; ?>

            <?php if ( has_post_thumbnail() ) {
                $post_id = get_the_ID();
                $post_thumbnail_id = get_post_thumbnail_id( $post_id );
                list($src, $width, $height) = wp_get_attachment_image_src($post_thumbnail_id, 'large');
            } ?>

            <a class="image-hover pinterest-share-button" href="<?php echo get_permalink(); ?>" target="_blank" data-media-src="<?php echo $src; ?>"><img src="<?php echo $image_src; ?>" /></a>

        <?php endif; ?>

        <?php if ( $image_src = get_option( 'webpm_sharing_facebook_button', THEME_URI.'/img/share-buttons/facebook.png' ) ) : ?>

            <a class="image-hover facebook-share-button" target="_blank" onclick="return !window.open(this.href, 'Facebook', 'width=640,height=300')" href="http://www.facebook.com/sharer/sharer.php?u=<?php echo urlencode(get_permalink()); ?>"><img src="<?php echo $image_src; ?>" /></a>

        <?php endif; ?>

        <?php if ( $image_src = get_option( 'webpm_sharing_twitter_button', THEME_URI.'/img/share-buttons/twitter.png' ) ) : ?>

            <a target="_blank" onclick="return !window.open(this.href, 'Twitter', 'width=500,height=430')" href="https://twitter.com/share?url=<?php echo urlencode(get_permalink()); ?>" class="image-hover twitter-share-button" data-lang="en"><img src="<?php echo $image_src; ?>" /></a>

        <?php endif; ?>

        <?php if ( $image_src = get_option( 'webpm_sharing_email_button', THEME_URI.'/img/share-buttons/email.png' ) ) : ?>

            <a title="Share by Email" class="image-hover email-share-button" target="_blank" href="mailto:?subject=&amp;body=<?php echo urlencode(get_permalink()); ?>"><img src="<?php echo $image_src; ?>" /></a>

        <?php endif; ?>

    </p>

    <?php
}

/**
 * the_heading 
 * 
 * @access public
 * @return void
 */
function the_heading() {
    global $post;
    ?>
    <?php if ( $h1 = get_post_meta( $post->ID, '_webpm_h1', true ) ) : ?>

        <?php echo apply_filters('the_title', $h1); ?>

    <?php else : ?>

        <?php the_title(); ?>

    <?php endif; ?>
    <?php
}

/**
 * the_copyright_text 
 * 
 * @access public
 * @return void
 */
function the_copyright_text() {
    $footer_text = "Copyright © ".date("Y")." ".get_bloginfo('name').". Site Made with ♥ by <a href=\"http://angiemakes.com\">Angie Makes</a>";
    //$footer_text = esc_html( $footer_text );
    //$footer_text = str_replace( 'Angie Makes', '<a href="http://angiemakes.com">Angie Makes</a>', $footer_text );

    echo $footer_text;
}

/**
 * the_date 
 * 
 * @access public
 * @return void
 */
function the_pub_date() {
    ?>

    <time datetime="<?php echo the_time('Y-m-j'); ?>" pubdate><?php the_time(get_option('date_format')); ?></time>
        
    <?php
}
?>
