<?php
/******************************************************************
Author: Chris Baldelomar
URL: http://webplantmedia.com

This file handles the admin area and functions.
You can use this file to make changes to the
dashboard. Updates to this page are coming soon.
It's turned off by default, but you can call it
via the functions file.

Special Thanks for code & inspiration to:
@jackmcconnell - http://www.voltronik.co.uk/
Digging into WP - http://digwp.com/2010/10/customize-wordpress-dashboard/
******************************************************************/

/**
 * Register settings to allow a user to select a template
 */
add_filter( 'admin_init', 'webpm_register_settings_fields' );

/**
 * Created a theme options page under Appearence menu 
 */
add_action( 'admin_menu', 'webpm_custom_options' );

/**
 * Define custom css for the admin section
 */
add_action('admin_enqueue_scripts', 'webpm_admin_enqueue_scripts');

if ( defined('WP_LOCAL_DEV') && constant('WP_LOCAL_DEV') ) {
    add_action('admin_footer', 'webpm_admin_footer');
}

/**
 * Add custom input box in media panel to save hyperlinks 
 */
add_filter( "attachment_fields_to_edit", "webpm_attachment_fields_to_edit", null, 2 ); 

/**
 * Save custom input box value in a custom field
 */
add_filter( "attachment_fields_to_save", "webpm_attachment_fields_to_save", null, 2 );

/**
 * Removing the dashboard widgets
 */
//add_action('admin_menu', 'disable_default_dashboard_widgets');

/**
 * resize large images to a smaller size
 */
// resize functions are from 3.5
if ( get_option( 'webpm_cap_upload_image_size', 1 ) ) {
    if ( $wp_version >= 3.5 ) {
        add_filter( 'wp_handle_upload', 'webpm_wp_handle_upload', 10, 2 );
    }
}

/**
 * Calling it only on the login page  
 */
//add_action('login_head', 'bones_login_css');
//add_filter('login_headerurl', 'bones_login_url');
//add_filter('login_headertitle', 'bones_login_title');
//add_filter('admin_footer_text', 'bones_custom_admin_footer');

/**
 * webpm_admin_enqueue_scripts
 *
 * this gives us some options for styling the admin area
 * 
 * @access public
 * @return void
 */
function webpm_admin_enqueue_scripts() {
    wp_register_style( 'webpm-admin', get_stylesheet_directory_uri() . '/css/admin.css', array(), WEBPM_VERSION, 'all' );
    wp_enqueue_style( 'webpm-admin' );

    wp_register_script( 'webpm-admin-js', get_stylesheet_directory_uri() . '/js/admin.js', array('jquery'), WEBPM_VERSION, false );
    wp_enqueue_script( 'webpm-admin-js' );

    if (isset($_GET['page']) && $_GET['page'] == 'webpm-sharing-buttons') {
        wp_enqueue_media();
        //wp_register_script('my-admin-js', WP_PLUGIN_URL.'/my-plugin/my-admin.js', array('jquery'));
        //wp_enqueue_script('my-admin-js');
    }
}

function webpm_admin_footer() {
    echo '<div class="testing-notice">Testing Site</div>';
}

/**
 * webpm_custom_options 
 *
 * Add the page "Select Template" in Appearence Menu
 * 
 * @access public
 * @return void
 */
function webpm_custom_options() {
    // add_theme_page( $page_title, $menu_title, $capability, $menu_slug, $function );
    //add_theme_page('Template Options', 'Select Template', 'read', 'webpm-select-template', 'webpm_select_template');

    // add_options_page( $page_title, $menu_title, $capability, $menu_slug, $function);
    add_options_page('Sharing Buttons', 'Sharing Buttons', 'read', 'webpm-sharing-buttons', 'webpm_sharing_buttons');
}

/**
 * register_general_settings_fields 
 * 
 * Adding dropdown for template option in General Settings
 *
 * @access public
 * @return void
 */
function webpm_register_settings_fields() {
    // register_setting( $option_group, $option_name, $sanitize_callback );
    //register_setting( 'webpm-template-group', 'webpm_template' );

    // add_settings_section( $id, $title, $callback, $page );
    // @page should match @menu_slug from add_theme_page
    //add_settings_section( 'webpm-template-section', '', 'webpm_template_settings_display', 'webpm-select-template' );

    // add_settings_field( $id, $title, $callback, $page, $section, $args );
    // @page should match @menu_slug from add_theme_page
    // @section the section you added with add_settings_section
    //add_settings_field('webpm_template', '<label for="webpm_template">'.__('Template' , 'webplantmedia' ).'</label>' , 'field_html_webpm_template', 'webpm-select-template', 'webpm-template-section' );

    // Upload Section
    register_setting( 'media', 'webpm_cap_upload_image_size' );
    add_settings_field('webpm_cap_upload_image_size', '<label for="webpm_cap_upload_image_size">'.__('Cap Upload Image Size' , 'webplantmedia' ).'</label>' , 'field_html_cap_upload_image_size', 'media', 'uploads' );

    // Gallery Section
    add_settings_section( 'webpm-media-section', 'Gallery Display', 'webpm_media_section_display', 'media' );
    register_setting( 'media', 'webpm_disable_gallery' );
    add_settings_field('webpm_disable_gallery', __('Disable Gallery' , 'webplantmedia' ) , 'field_html_webpm_disable_gallery', 'media', 'webpm-media-section' );

    // Carousel Section
    add_settings_section( 'webpm-media-carousel-section', 'Carousel Display', 'webpm_media_section_display', 'media' );

    register_setting( 'media', 'webpm_carousel_interval', 'intval' );
    add_settings_field('webpm_carousel_interval', '<label for="webpm_carousel_interval">'.__('Carousel Interval'.'</label>' , 'webplantmedia' ) , 'field_html_webpm_carousel_interval', 'media', 'webpm-media-carousel-section' );

    register_setting( 'media', 'webpm_carousel_caption', 'intval' );
    add_settings_field('webpm_carousel_caption', __('Display Caption' , 'webplantmedia' ) , 'field_html_webpm_carousel_caption', 'media', 'webpm-media-carousel-section' );

    register_setting( 'media', 'webpm_carousel_controls', 'intval' );
    add_settings_field('webpm_carousel_controls', __('Display Control Arrows' , 'webplantmedia' ) , 'field_html_webpm_carousel_controls', 'media', 'webpm-media-carousel-section' );

    register_setting( 'media', 'webpm_carousel_width', 'intval' );
    register_setting( 'media', 'webpm_carousel_height', 'intval' );
    add_settings_field('webpm_carousel_size', __('Carousel Size' , 'webplantmedia' ) , 'field_html_webpm_carousel_size', 'media', 'webpm-media-carousel-section' );

    // General Options
    register_setting( 'general', 'webpm_email_to', 'webpm_sanitize_emails' );
    add_settings_field('webpm_email_to', '<label for="webpm_email_to">'.__('Send Emails To' , 'webplantmedia' ).'</label>' , 'field_html_webpm_email_to', 'general' );

    // Sharing Buttons
    // register_setting( $option_group, $option_name, $sanitize_callback );
    register_setting( 'webpm-sharing-buttons-group', 'webpm_sharing_pinterest_button', 'esc_url_raw' );
    register_setting( 'webpm-sharing-buttons-group', 'webpm_sharing_facebook_button', 'esc_url_raw' );
    register_setting( 'webpm-sharing-buttons-group', 'webpm_sharing_twitter_button', 'esc_url_raw' );
    register_setting( 'webpm-sharing-buttons-group', 'webpm_sharing_email_button', 'esc_url_raw' );
    register_setting( 'webpm-sharing-buttons-group', 'webpm_sharing_pinit_image_hover' );
    register_setting( 'webpm-sharing-buttons-group', 'webpm_sharing_show_buttons' );

    // add_settings_section( $id, $title, $callback, $page );
    // @page should match @menu_slug from add_theme_page
    add_settings_section( 'webpm-sharing-buttons-section', '', 'webpm_sharing_buttons_settings_display', 'webpm-sharing-buttons' );

    // add_settings_field( $id, $title, $callback, $page, $section, $args );
    // @page should match @menu_slug from add_theme_page
    // @section the section you added with add_settings_section
    add_settings_field('webpm_sharing_show_buttons', '<label for="webpm_sharing_show_buttons">'.__('Show Share Buttons' , 'webplantmedia' ).'</label>' , 'field_html_webpm_sharing_show_buttons', 'webpm-sharing-buttons', 'webpm-sharing-buttons-section' );
    add_settings_field('webpm_sharing_pinterest_button', '<label for="webpm_sharing_pinterest_button">'.__('Pinterest Button' , 'webplantmedia' ).'</label>' , 'field_html_webpm_sharing_pinterest_button', 'webpm-sharing-buttons', 'webpm-sharing-buttons-section' );
    add_settings_field('webpm_sharing_facebook_button', '<label for="webpm_sharing_facebook_button">'.__('Facebook Button' , 'webplantmedia' ).'</label>' , 'field_html_webpm_sharing_facebook_button', 'webpm-sharing-buttons', 'webpm-sharing-buttons-section' );
    add_settings_field('webpm_sharing_twitter_button', '<label for="webpm_sharing_twitter_button">'.__('Twitter Button' , 'webplantmedia' ).'</label>' , 'field_html_webpm_sharing_twitter_button', 'webpm-sharing-buttons', 'webpm-sharing-buttons-section' );
    add_settings_field('webpm_sharing_email_button', '<label for="webpm_sharing_email_button">'.__('Email Button' , 'webplantmedia' ).'</label>' , 'field_html_webpm_sharing_email_button', 'webpm-sharing-buttons', 'webpm-sharing-buttons-section' );
    add_settings_field('webpm_sharing_pinit_image_hover', '<label for="webpm_sharing_pinit_image_hover">'.__('Pin It Image Hover' , 'webplantmedia' ).'</label>' , 'field_html_webpm_sharing_pinit_image_hover', 'webpm-sharing-buttons', 'webpm-sharing-buttons-section' );


    // Media Settings
    if ( !get_option( 'webpm_disable_gallery' ) ) {
        add_action( 'wp_enqueue_media', 'webpm_wp_enqueue_media' );
        add_action( 'print_media_templates', 'webpm_print_media_templates' );
    }
}

/**
 * webpm_attachment_fields_to_edit 
 *
 * Adds custom fields to attachment page 
 * http://wpengineer.com/2076/add-custom-field-attachment-in-wordpress/ 
 *
 * @param mixed $form_fields 
 * @param mixed $post 
 * @access public
 * @return void
 */
function webpm_attachment_fields_to_edit( $form_fields, $post) {
    $form_fields['webpm_custom_image_link'] = array(  
        "label" => __( "Link To" ),  
        "input" => "text",
        "value" => get_post_meta( $post->ID, "_webpm_custom_image_link", true )  
    );        
    return $form_fields;  
}  

/**
 * webpm_attachment_fields_to_save 
 *
 * Save custom input in media panel to custom field
 * and validate hyperlink inserted.
 * 
 * @param mixed $post 
 * @param mixed $attachment 
 * @access public
 * @return void
 */
function webpm_attachment_fields_to_save( $post, $attachment) {
    if( isset( $attachment['webpm_custom_image_link'] ) ){  
        update_post_meta( $post['ID'], '_webpm_custom_image_link', esc_url_raw( $attachment['webpm_custom_image_link'] ) );  
    }  
    return $post;  
}  

/**
 * Registers/enqueues the gallery settings admin js.
 */
function webpm_wp_enqueue_media() {
    wp_register_script( 'webpm-gallery-settings', get_stylesheet_directory_uri() . '/js/gallery-settings.js', array( 'media-views' ), WEBPM_VERSION, true );

    wp_enqueue_script( 'webpm-gallery-settings' );
}

/**
 * Outputs a view template which can be used with wp.media.template
 */
function webpm_print_media_templates() {
    $gallery_types = array( 
        'default' => __( 'Mosaic', 'webpm' ),
        'grid' => __( 'Thumbnail Grid', 'webpm' ),
        'carousel' => __( 'Carousel', 'webpm' )
    );
    ?>
    <script type="text/html" id="tmpl-webpm-gallery-settings">
        <label class="setting">
            <span><?php _e( 'Layout', 'webpm' ); ?></span>
            <select class="layout" name="layout" data-setting="layout">
                <?php foreach ( $gallery_types as $value => $caption ) : ?>
                    <option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, 'default' ); ?>><?php echo esc_html( $caption ); ?></option>
                <?php endforeach; ?>
            </select>
        </label>

        <label class="setting">
            <span><?php _e( 'Custom Links' ); ?></span>
            <input type="checkbox" name="custom_links" data-setting="custom_links" />
        </label>

        <label class="setting">
            <span><?php _e( 'Show Captions' ); ?></span>
            <input type="checkbox" name="show_captions" data-setting="show_captions" />
        </label>
    </script>
    <?php
}

/**
 * field_html_webpm_email_to 
 * 
 * @access public
 * @return void
 */
function field_html_webpm_email_to() {
    $val = get_option( 'webpm_email_to' );

    echo '<input name="webpm_email_to" id="webpm_email_to" placeholder="youremail@domain.com, youremail2@domain.com" class="regular-text ltr" type="text" value="'.esc_attr($val).'" />';
    echo '<p class="description">Insert email addresses separated by commas. This is only used by the <code>[contact]</code> shortcode to send emails to.</p>';
}

function field_html_cap_upload_image_size() {
    $checked = '';
    if ( get_option( 'webpm_cap_upload_image_size', 1 ) )
        $checked = 'checked="checked"';

    echo '<label for="webpm_cap_upload_image_size"><input name="webpm_cap_upload_image_size" id="webpm_cap_upload_image_size" type="checkbox" value="1" '.$checked.' /> Original images larger than 1100 pixels will be automatically resized.</label>';
    echo '<p class="description"> You must have Wordpress <code>version 3.5</code> or higher.</p>';
}

/**
 * field_html_sharing_pinterest_button 
 * 
 * @access public
 * @return void
 */
function field_html_webpm_sharing_pinterest_button() {
    $brand = "Pinterest";
    $id = "webpm_sharing_pinterest_button";
    $default = THEME_URI.'/img/share-buttons/pinterest.png';
    $val = get_option( 'webpm_sharing_pinterest_button', $default );
    $delete = THEME_URI.'/img/ico-delete.png';

    echo '<input name="'.$id.'" id="'.$id.'" class="regular-text ltr upload-input" type="text" value="'.esc_attr($val).'" />';
    echo '<a href="#" class="button webpm_upload_image inline-button" data-target="#'.$id.'" title="Add Media"><span class="wp-media-buttons-icon"></span> Add Media</a>';
    echo '<a href="#" class="button restore_default inline-button" data-restore="'.esc_attr($default).'" data-target="#'.$id.'">Restore Default</a>';
    echo '<a href="#" class="button delete_image inline-button" data-target="#'.$id.'">Delete</a>';
    echo '<p class="description">Insert image path for your '.$brand.' Button.</p>';
    echo '<p class="preview-image"><img id="'.$id.'_preview" src="'.esc_attr($val).'" /></p>';
}

/**
 * field_html_webpm_sharing_facebook_button 
 * 
 * @access public
 * @return void
 */
function field_html_webpm_sharing_facebook_button() {
    $brand = "Facebook";
    $id = "webpm_sharing_facebook_button";
    $default = THEME_URI.'/img/share-buttons/facebook.png';
    $val = get_option( 'webpm_sharing_facebook_button', $default );

    echo '<input name="'.$id.'" id="'.$id.'" class="regular-text ltr upload-input" type="text" value="'.esc_attr($val).'" />';
    echo '<a href="#" class="button webpm_upload_image inline-button" data-target="#'.$id.'" title="Add Media"><span class="wp-media-buttons-icon"></span> Add Media</a>';
    echo '<a href="#" class="button restore_default inline-button" data-restore="'.esc_attr($default).'" data-target="#'.$id.'">Restore Default</a>';
    echo '<a href="#" class="button delete_image inline-button" data-target="#'.$id.'">Delete</a>';
    echo '<p class="description">Insert image path for your '.$brand.' Button.</p>';
    echo '<p class="preview-image"><img id="'.$id.'_preview" src="'.esc_attr($val).'" /></p>';
}

/**
 * field_html_webpm_sharing_twitter_button 
 * 
 * @access public
 * @return void
 */
function field_html_webpm_sharing_twitter_button() {
    $brand = "Twitter";
    $id = "webpm_sharing_twitter_button";
    $default = THEME_URI.'/img/share-buttons/twitter.png';
    $val = get_option( 'webpm_sharing_twitter_button', $default );

    echo '<input name="'.$id.'" id="'.$id.'" class="regular-text ltr upload-input" type="text" value="'.esc_attr($val).'" />';
    echo '<a href="#" class="button webpm_upload_image inline-button" data-target="#'.$id.'" title="Add Media"><span class="wp-media-buttons-icon"></span> Add Media</a>';
    echo '<a href="#" class="button restore_default inline-button" data-restore="'.esc_attr($default).'" data-target="#'.$id.'">Restore Default</a>';
    echo '<a href="#" class="button delete_image inline-button" data-target="#'.$id.'">Delete</a>';
    echo '<p class="description">Insert image path for your '.$brand.' Button.</p>';
    echo '<p class="preview-image"><img id="'.$id.'_preview" src="'.esc_attr($val).'" /></p>';
}

/**
 * field_html_webpm_sharing_email_button 
 * 
 * @access public
 * @return void
 */
function field_html_webpm_sharing_email_button() {
    $brand = "Custom";
    $id = "webpm_sharing_email_button";
    $default = THEME_URI.'/img/share-buttons/email.png';
    $val = get_option( 'webpm_sharing_email_button', $default );

    echo '<input name="'.$id.'" id="'.$id.'" class="regular-text ltr upload-input" type="text" value="'.esc_attr($val).'" />';
    echo '<a href="#" class="button webpm_upload_image inline-button" data-target="#'.$id.'" title="Add Media"><span class="wp-media-buttons-icon"></span> Add Media</a>';
    echo '<a href="#" class="button restore_default inline-button" data-restore="'.esc_attr($default).'" data-target="#'.$id.'">Restore Default</a>';
    echo '<a href="#" class="button delete_image inline-button" data-target="#'.$id.'">Delete</a>';
    echo '<p class="description">Insert image path for your '.$brand.' Button.</p>';
    echo '<p class="preview-image"><img id="'.$id.'_preview" src="'.esc_attr($val).'" /></p>';
}

/**
 * field_html_webpm_sharing_pinit_image_hover 
 * 
 * @access public
 * @return void
 */
function field_html_webpm_sharing_pinit_image_hover() {
    $checked = '';
    if ( get_option( 'webpm_sharing_pinit_image_hover', 1 ) )
        $checked = 'checked="checked"';

    echo '<label for="webpm_sharing_pinit_image_hover"><input name="webpm_sharing_pinit_image_hover" id="webpm_sharing_pinit_image_hover" type="checkbox" value="1" '.$checked.' /> Make it easy for your readers to pin your images to Pinterest when they hover over your images.</label>';
}

/**
 * field_html_webpm_sharing_show_buttons 
 * 
 * @access public
 * @return void
 */
function field_html_webpm_sharing_show_buttons() {
    $checked = '';
    if ( get_option( 'webpm_sharing_show_buttons', 1 ) )
        $checked = 'checked="checked"';

    echo '<label for="webpm_sharing_show_buttons"><input name="webpm_sharing_show_buttons" id="webpm_sharing_show_buttons" type="checkbox" value="1" '.$checked.' /> Show share buttons at the bottom of your post.</label>';
}

/**
 * webpm_sanitize_emails 
 * 
 * @access public
 * @return void
 */
function webpm_sanitize_emails( $email_to ) {
    $emails = explode( ',', $email_to );
    foreach( $emails as $key => $email ) {
        $email = sanitize_email( $email );
        if ( is_email( $email ) )
            $emails[$key] = $email;
        else
            unset( $emails[$key] );
    }
    $email_to = implode( ',', $emails );

    return trim($email_to);
}

/**
 * field_html_webpm_carousel_size 
 * 
 * @access public
 * @return void
 */
function field_html_webpm_carousel_size() {
    $width = get_option( 'webpm_carousel_width', CAROUSEL_IMAGE_WIDTH );
    $height = get_option( 'webpm_carousel_height', CAROUSEL_IMAGE_HEIGHT );

    echo '
        <label for="webpm_carousel_width">Max Width</label>
        <input name="webpm_carousel_width" type="number" step="1" min="0" id="webpm_carousel_width" value="'.$width.'" class="small-text">
        <label for="webpm_carousel_height">Max Height</label>
        <input name="webpm_carousel_height" type="number" step="1" min="0" id="webpm_carousel_height" value="'.$height.'" class="small-text">
    ';
}

/**
 * field_html_webpm_disable_gallery 
 * 
 * @access public
 * @return void
 */
function field_html_webpm_disable_gallery() {
    $checked = '';
    if ( $val = get_option( 'webpm_disable_gallery' ) )
        $checked = 'checked="checked"';

    echo '<label for="webpm_disable_gallery"><input name="webpm_disable_gallery" id="webpm_disable_gallery" type="checkbox" value="1" '.$checked.' /> Disable custom gallery provided by theme.</label>';
}

/**
 * field_html_webpm_carousel_caption 
 * 
 * @access public
 * @return void
 */
function field_html_webpm_carousel_caption() {
    $checked = '';
    if ( get_option( 'webpm_carousel_caption', 1 ) )
        $checked = 'checked="checked"';

    echo '<label for="webpm_carousel_caption"><input name="webpm_carousel_caption" id="webpm_carousel_caption" type="checkbox" value="1" '.$checked.' /> Display the carousel caption on the home page.</label>';
}

/**
 * field_html_webpm_carousel_controls 
 * 
 * @access public
 * @return void
 */
function field_html_webpm_carousel_controls() {
    $checked = '';
    if ( get_option( 'webpm_carousel_controls', 1 ) )
        $checked = 'checked="checked"';

    echo '<label for="webpm_carousel_controls"><input name="webpm_carousel_controls" id="webpm_carousel_controls" type="checkbox" value="1" '.$checked.' /> Display the carousel control arrows on the home page.</label>';
}

/**
 * field_html_webpm_carousel_interval 
 * 
 * @access public
 * @return void
 */
function field_html_webpm_carousel_interval() {
    if ( !$val = get_option( 'webpm_carousel_interval' ) )
        $val = 0;

    $html = '<select name="webpm_carousel_interval" id="webpm_carousel_interval">';
    $html .= '<option val="0" '.selected($val, 0, false).'>Pause</option>';
    $html .= '<option val="2" '.selected($val, 2, false).'>2</option>';
    $html .= '<option val="3" '.selected($val, 3, false).'>3</option>';
    $html .= '<option val="4" '.selected($val, 4, false).'>4</option>';
    $html .= '<option val="5" '.selected($val, 5, false).'>5</option>';
    $html .= '<option val="6" '.selected($val, 6, false).'>6</option>';
    $html .= '<option val="7" '.selected($val, 7, false).'>7</option>';
    $html .= '<option val="8" '.selected($val, 8, false).'>8</option>';
    $html .= '<option val="9" '.selected($val, 9, false).'>9</option>';
    $html .= '<option val="10" '.selected($val, 10, false).'>10</option>';
    $html .= '<option val="11" '.selected($val, 11, false).'>11</option>';
    $html .= '<option val="12" '.selected($val, 12, false).'>12</option>';
    $html .= '<option val="13" '.selected($val, 13, false).'>13</option>';
    $html .= '<option val="14" '.selected($val, 14, false).'>14</option>';
    $html .= '<option val="15" '.selected($val, 15, false).'>15</option>';
    $html .= '<option val="16" '.selected($val, 16, false).'>16</option>';
    $html .= '<option val="17" '.selected($val, 17, false).'>17</option>';
    $html .= '<option val="18" '.selected($val, 18, false).'>18</option>';
    $html .= '<option val="19" '.selected($val, 19, false).'>19</option>';
    $html .= '<option val="20" '.selected($val, 20, false).'>20</option>';
    $html .= '</select>';
    $html .= '<p class="description">Choose how many seconds should go by before the carousel slides to the next image.</p>';

    echo $html;
}

/**
 * webpm_media_section_display 
 * 
 * @access public
 * @return void
 */
function webpm_media_section_display() {
    // nothing
}

/**
 * webpm_template_settings_display 
 *
 * This function displays additional output when 
 * do_settings_section() is called.
 * 
 * @access public
 * @return void
 */
function webpm_template_settings_display() {
    // nothing
}

/**
 * webpm_sharing_buttons_settings_display 
 * 
 * @access public
 * @return void
 */
function webpm_sharing_buttons_settings_display() {
    // nothing
}

/**
 * webpm_sharing_buttons 
 * 
 * @access public
 * @return void
 */
function webpm_sharing_buttons() {
    ?>
    <div class="wrap">
        <?php screen_icon(); ?>
        <h2>Sharing Buttons</h2>
        <form method="post" action="options.php">
            <?php
            // settings_fields( $option_group )
            // @option_group A settings group name. This should match the group name used in register_setting()
            settings_fields( 'webpm-sharing-buttons-group' );

            // do_settings_fields( $page, $section )
            // @page Slug title of the admin page whose settings fields you want to show, should match the group name used in add_settings_section()
            // @section Slug title of the settings section whose fields you want to show. This should match the section ID used in add_settings_section()
            //do_settings_fields( 'webpm-sharing-buttons', 'webpm-sharing-buttons-section' );

            // do_settings_sections( $page ) 
            // The slug name of the page whose settings sections you want to output. This should match the page name used in add_settings_section()
            do_settings_sections( 'webpm-sharing-buttons' );
            ?>

            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

/**
 * webpm_select_template 
 *
 * add_theme_page calls this function to display
 * the settings page.
 * 
 * @access public
 * @return void
 */
function webpm_select_template() {
    ?>
    <div class="wrap">
        <?php screen_icon(); ?>
        <h2>Select Your Template</h2>
        <form method="post" action="options.php">
            <?php
            // settings_fields( $option_group )
            // @option_group A settings group name. This should match the group name used in register_setting()
            settings_fields( 'webpm-template-group' );

            // do_settings_fields( $page, $section )
            // @page Slug title of the admin page whose settings fields you want to show, should match the group name used in add_settings_section()
            // @section Slug title of the settings section whose fields you want to show. This should match the section ID used in add_settings_section()
            //do_settings_fields( 'webpm-select-template', 'webpm-template-section' );

            // do_settings_sections( $page ) 
            // The slug name of the page whose settings sections you want to output. This should match the page name used in add_settings_section()
            do_settings_sections( 'webpm-select-template' );
            ?>

            <?php submit_button(); ?>
        </form>
    </div>
    <?php
}

/**
 * field_html_webpm_template 
 *
 * This function displays the individual dropdown
 * for selecting a template
 * 
 * @access public
 * @return void
 */
function field_html_webpm_template() {
    $options = webpm_dropdown_templates( get_option( 'webpm_template', 'default' ) );
    echo '<select name="webpm_template" id="webpm_template">'.$options.'</select>';
}

/**
 * webpm_dropdown_templates 
 * 
 * Print out <option> html elements for templates
 *
 * @param string $selected id for the template that should be already selected
 * @access public
 * @return void
 */
function webpm_dropdown_templates( $selected = false ) {
    $html = '';

    $templates = webpm_get_templates();

    foreach ( $templates as $id => $name ) {
        if ( $selected == $id )
            $html .= "\n\t<option selected='selected' value='" . esc_attr($id) . "'>$name</option>";
        else
            $html .= "\n\t<option value='" . esc_attr($id) . "'>$name</option>";
    }

    return $html;
}

/**
 * webpm_wp_handle_upload 
 * 
 * @param mixed $args 
 * @param mixed $action 
 * @access public
 * @return void
 */
function webpm_wp_handle_upload( $args, $action ) {
    global $wp_version;

    if ( $action != 'upload' )
        return $args;

    if ( !array_key_exists( 'file', $args ) )
        return $args;

    $editor = wp_get_image_editor( $args['file'] );

    if ( ! is_wp_error( $editor ) ) {
        $editor->set_quality( 100 );
        $resized = $editor->resize( MAX_IMAGE_LENGTH, MAX_IMAGE_LENGTH, false );
        if ( $resized ) {
            $editor->save( $args['file'], $args['type'] );
        }
        $editor->set_quality( 90 );
    }

    return $args;
}

/**
 * disable_default_dashboard_widgets 
 * 
 * @access public
 * @return void
 */
function disable_default_dashboard_widgets() {
    // remove_meta_box('dashboard_right_now', 'dashboard', 'core');    // Right Now Widget
    remove_meta_box('dashboard_recent_comments', 'dashboard', 'core'); // Comments Widget
    remove_meta_box('dashboard_incoming_links', 'dashboard', 'core');  // Incoming Links Widget
    remove_meta_box('dashboard_plugins', 'dashboard', 'core');         // Plugins Widget

    // remove_meta_box('dashboard_quick_press', 'dashboard', 'core');  // Quick Press Widget
    remove_meta_box('dashboard_recent_drafts', 'dashboard', 'core');   // Recent Drafts Widget
    remove_meta_box('dashboard_primary', 'dashboard', 'core');         //
    remove_meta_box('dashboard_secondary', 'dashboard', 'core');       //

    // removing plugin dashboard boxes
    remove_meta_box('yoast_db_widget', 'dashboard', 'normal');         // Yoast's SEO Plugin Widget

    /*
    have more plugin widgets you'd like to remove?
    share them with us so we can get a list of
    the most commonly used. :D
    https://github.com/eddiemachado/bones/issues
    */
}

/**
 * bones_login_css 
 *
 * calling your own login css so you can style it
 *
 * @access public
 * @return void
 */
function bones_login_css() {
    /* I couldn't get wp_enqueue_style to work :( */
    echo '<link rel="stylesheet" href="' . get_stylesheet_directory_uri() . '/inc/css/login.css">';
}

/**
 * bones_login_url 
 *
 * changing the logo link from wordpress.org to your site
 *
 * @access public
 * @return void
 */
function bones_login_url() {
    return home_url();
}

/**
 * bones_login_title 
 *
 * changing the alt text on the logo to show your site name
 *
 * @access public
 * @return void
 */
function bones_login_title() {
    return get_option('blogname');
}

/**
 * bones_custom_admin_footer 
 *
 * Custom Backend Footer
 *
 * @access public
 * @return void
 */
function bones_custom_admin_footer() {
    echo '<span id="footer-thankyou">Developed by <a href="http://webplantmedia.com" target="_blank">Web Plant Media</a></span>. Built using <a href="http://carousel.webplantmedia.com" target="_blank">Carousel 3D Theme</a>.';
}

?>
