<?php
/******************************************************************
Author: Chris Baldelomar
URL: http://webplantmedia.com

This is the core 'bones' file where all of the hooks, action
and filters should be placed. If you have any custom functions
or libraries you would like to include, it's best to put them
in the functions.php file
******************************************************************/

/**
 * we're firing all out initial functions at the start 
 */
add_action('after_setup_theme','bones_init', 15);

/**
 * Peform actions after we enable our theme 
 */
//add_action('after_switch_theme', 'webpm_theme_activation');

/**
 * webpm_theme_activation 
 *
 * Peform actions after we enable our theme.
 * 
 * @access public
 * @return void
 */
function webpm_theme_activation() {
    // Place actions here after theme is selected
}

/**
 * bones_init 
 *
 * Let's fire off all the functions
 * and tools. I put it up here so it's
 * right up top and clean.
 * 
 * @access public
 * @return void
 */
function bones_init() {
    /**
     * Set all image dimensions for this theme
     */

    add_image_size( 'bootstrap-thumbnail-cropped', 260, 260, true );
    add_image_size( 'bootstrap-thumbnail', 260, 260, false );
    add_image_size( 'bootstrap-thumbnail-x', 260, 999, false );
    add_image_size( 'bootstrap-medium-cropped', 400, 400, true );
    add_image_size( 'bootstrap-medium', 400, 400, false );
    add_image_size( 'bootstrap-medium-x', 400, 999, false );
    add_image_size( 'bootstrap-large', 780, 600, false );
    add_image_size( 'bootstrap-large-x', 780, 999, false );
    add_image_size( 'bootstrap-large-cropped', 780, 495, true );
    add_image_size( 'bootstrap-image-link', 250, 160, true );

    $width = get_option( 'webpm_carousel_width', CAROUSEL_IMAGE_WIDTH );
    $height = get_option( 'webpm_carousel_height', CAROUSEL_IMAGE_HEIGHT );
    add_image_size( 'bootstrap-full-cropped', $width, $height, true );

    add_filter( 'image_size_names_choose', 'webpm_image_size_names_choose' );

    /**
     * Head cleanup (remove rsd, uri links, junk css, ect).
     * These function definitions can be found in this file.
     */

    // launching operation cleanup
    add_action('init', 'bones_head_cleanup');

    // remove WP version from RSS
    add_filter('the_generator', 'bones_rss_version');

    // remove pesky injected css for recent comments widget
    add_filter( 'wp_head', 'bones_remove_wp_widget_recent_comments_style', 1 );

    // clean up comment styles in the head
    add_action('wp_head', 'bones_remove_recent_comments_style', 1);

    if ( !get_option( 'webpm_disable_gallery' ) ) {
        // filter default gallery structure
        add_filter( 'post_gallery', 'bootstrap_post_gallery', 10, 2 );

        // add our default media templates to jetpacks list
        //add_filter( 'jetpack_gallery_types', 'webpm_jetpack_gallery_types' );
    }
 
    // enqueue base scripts and styles
    add_action('wp_enqueue_scripts', 'bones_scripts_and_styles', 999);

    // ie conditional wrapper
    add_filter( 'style_loader_tag', 'bones_ie_conditional', 10, 2 );

    // launching this stuff after theme setup
    add_action('after_setup_theme','bones_theme_support');

    // adding sidebars to Wordpress (these are created in functions.php)
    add_action( 'widgets_init', 'bones_register_sidebars' );

    // cleaning up content on display
    //add_filter('the_content', 'bones_filter_the_content');

    // process shortcodes before wpautop
    add_filter('the_content', 'pre_process_shortcode', 7);

    // cleaning up content on save
    //add_filter('content_save_pre', 'webpm_content_save_pre' );

    // cleaning up excerpt
    add_filter('excerpt_more', 'bones_excerpt_more');

    // send email when logged out
    add_action( 'wp_ajax_nopriv_webpm-send-email', 'webpm_send_email' );

    // send email when logged in
    add_action( 'wp_ajax_webpm-send-email', 'webpm_send_email' );

    // enqueue any google fonts selected from theme options
    add_action( 'init', 'options_typography_google_fonts' );

    // customize the title based on use input from custom fields
    //add_filter('single_post_title', 'webpm_single_post_title', 10, 2);

    // add inline css from users saved style in theme options
    add_action('wp_head', 'options_css_styles');

    // Add social and tracking scripts
    add_action('wp_head', 'webpm_inline_javascript', 9999);

    // Add social and tracking scripts
    add_action('wp_footer', 'webpm_inline_javascript_footer', 9999);

    // Should allow for quick updates on pinterest RSS feed
    add_filter( 'wp_feed_cache_transient_lifetime', create_function('$rssLife', 'return 500;') );

    // Add to the class attribute in the body element
    add_filter( 'body_class', 'webpm_body_class', 10, 2 );

    // Add wrapper around embeded videos so we can make it responsive
    add_filter( 'embed_oembed_html', 'webpm_embed_oembed_html', 10, 4 );

    // Add btn class to comment reply link
    add_filter( 'comment_reply_link', 'webpm_comment_reply_link', 10, 4 );

    // Add btn class to comment edit link
    add_filter( 'edit_comment_link', 'webpm_edit_comment_link', 10, 2 );

    /**
     * The following function definitions are placed
     * in bootstrap-shortcodes.php and allow the wordpress
     * user to extend the look of their website using
     * Bootstrap displays and functions. 
     */

    // display company or team profiles
    //add_shortcode( 'profiles' , 'bootstrap_shortcode_profiles' );

    // display users portfolio or product page
    //add_shortcode( 'portfolio' , 'bootstrap_shortcode_portfolio' );

    // insert well
    //add_shortcode( 'well' , 'bootstrap_shortcode_well' );

    // insert contact form
    add_shortcode( 'contact' , 'bootstrap_shortcode_contact' );

    // insert pop google map
    //add_action( 'wp_footer', 'webpm_helper_modal_map' );

    // add testing notice
    if ( defined('WP_LOCAL_DEV') && constant('WP_LOCAL_DEV') ) {
        add_action( 'wp_footer', 'webpm_testing_notice' );
    }

    // insert button
    add_shortcode( 'button' , 'bootstrap_shortcode_button' );

    // create table
    //add_shortcode( 'table' , 'bootstrap_shortcode_table' );

    // insert pretty code 
    add_shortcode( 'code' , 'bootstrap_shortcode_displaycode' );

    // dummy filter so shortcode ban be strippable
    // http://betterwp.net/17-protect-shortcodes-from-wpautop-and-the-likes/
    //add_shortcode( 'code' , create_function( '$atts, $content', 'return $content;' ) );

    // insert <pre> element
    add_shortcode( 'pre' , 'bootstrap_shortcode_displaypre' );

    // insert <pre> element
    add_shortcode( 'html' , 'bootstrap_shortcode_displayhtml' );

    // add social icons from with row theme options
    add_shortcode( 'social_icons' , 'bootstrap_shortcode_social_icons' );

    // add social icons from theme options
    add_shortcode( 'social_media_icons' , 'webpm_shortcode_social_media_icons' );

    // filter social_url
    add_filter( 'webpm_social_url' , 'webpm_social_url', 10, 2 );

    // alter default excerpt length.
    add_filter('excerpt_length', 'webpm_excerpt_length');
}

function pre_process_shortcode($content) {
    global $shortcode_tags;

    // Backup current registered shortcodes and clear them all out
    $orig_shortcode_tags = $shortcode_tags;
    $shortcode_tags = array();

    // insert row
    add_shortcode( 'row' , 'bootstrap_shortcode_row' );
 
    // insert span
    add_shortcode( 'span' , 'bootstrap_shortcode_span' );

    // create collapsable paragraphs
    add_shortcode( 'accordion' , 'bootstrap_shortcode_accordion' );

    // create toggable tabs
    add_shortcode( 'tabs' , 'bootstrap_shortcode_tabs' );

    // Do the shortcode (only the one above is registered)
    $content = do_shortcode($content);
 
    // Put the original shortcodes back
    $shortcode_tags = $orig_shortcode_tags;
 
    return $content;
}

/**
 * webpm_image_size_names_choose 
 * 
 * @param mixed $sizes 
 * @access public
 * @return void
 */
function webpm_image_size_names_choose( $sizes ) {
    $sizes['bootstrap-large'] = 'Post Width';
    $sizes['bootstrap-thumbnail'] = 'Sidebar Width';
    $sizes['bootstrap-image-link'] = 'Image Link';
 
    return $sizes;
}
 
/**
 * bones_head_cleanup 
 * 
 * The default wordpress head is
 * a mess. Let's clean it up by
 * removing all the junk we don't
 * need.
 *
 * @access public
 * @return void
 */
function bones_head_cleanup() {
    // category feeds
    // remove_action( 'wp_head', 'feed_links_extra', 3 );
    // post and comment feeds
    // remove_action( 'wp_head', 'feed_links', 2 );
    // EditURI link
    remove_action( 'wp_head', 'rsd_link' );
    // windows live writer
    remove_action( 'wp_head', 'wlwmanifest_link' );
    // index link
    remove_action( 'wp_head', 'index_rel_link' );
    // previous link
    remove_action( 'wp_head', 'parent_post_rel_link', 10, 0 );
    // start link
    remove_action( 'wp_head', 'start_post_rel_link', 10, 0 );
    // links for adjacent posts
    remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0 );
    // WP version
    remove_action( 'wp_head', 'wp_generator' );

}

/**
 * webpm_jetpack_gallery_types 
 * 
 * @param mixed $types 
 * @access public
 * @return void
 */
function webpm_jetpack_gallery_types( $types ) {
    $types['collage'] = __( 'Collage', 'jetpack' );
    $types['carousel'] = __( 'Carousel', 'jetpack' );

    return $types;
}

/**
 * bones_rss_version 
 *
 * remove WP version from RSS
 *
 * @access public
 * @return void
 */
function bones_rss_version() {
    return ''; 
}

/**
 * webpm_edit_comment_link 
 *
 * filter html and add btn class to edit comment link
 * 
 * @param string $link 
 * @param int $comment_id 
 * @access public
 * @return void
 */
function webpm_edit_comment_link( $link, $comment_id ) {
    $link = str_replace( '<a class="', '<a class="btn btn-primary ', $link );

    return $link;
}

/**
 * webpm_single_post_title 
 * 
 * @param mixed $_post_title 
 * @param mixed $_post 
 * @access public
 * @return void
 */
function webpm_single_post_title($_post_title, $_post) {
    if ( $title = get_post_meta( $_post->ID, '_webpm_meta_title', true ) )
        return $title;

    return $_post_title;
}

/**
 * webpm_inline_javascript 
 *
 * Insert inline javascript before the closing
 * of the head section. Used primarly for social
 * and tracking scripts.
 * 
 * @access public
 * @return void
 */
function webpm_inline_javascript() {
    if ( $js = of_get_option( 'javascript_header' ) ) {
        echo $js;
    }
    ?>
    <script type="text/javascript">
        (function(d){
          var f = d.getElementsByTagName('SCRIPT')[0], p = d.createElement('SCRIPT');
          p.type = 'text/javascript';
          p.async = true;
          p.src = '//assets.pinterest.com/js/pinit.js';
          f.parentNode.insertBefore(p, f);
        }(document));
    </script>
    <?php
}

/**
 * webpm_inline_javascript_footer 
 * 
 * @access public
 * @return void
 */
function webpm_inline_javascript_footer() {
    if ( $js = of_get_option( 'javascript_footer' ) ) {
        echo $js;
    }
}

/**
 * webpm_comment_reply_link 
 *
 * filter the html for the comment reply link
 * 
 * @param string $link 
 * @param array $args 
 * @param object $comment 
 * @param object $post 
 * @access public
 * @return void
 */
function webpm_comment_reply_link( $link, $args, $comment, $post ) {
    $link = str_replace( '<a class=\'', '<a class=\'btn btn-primary ', $link );

    return $link;
}

/**
 * webpm_embed_oembed_html 
 *
 * add a wrapping element so we can
 * make embeded videos responsive.
 * 
 * @param string $html 
 * @param url $url 
 * @param array $attr 
 * @param int $post_ID 
 * @access public
 * @return void
 */
function webpm_embed_oembed_html( $html, $url, $attr, $post_ID ) {
    return '<div class="video-container">' . $html . '</div>';
}

/**
 * bones_remove_wp_widget_recent_comments_style 
 *
 * remove injected CSS for recent comments widget
 *
 * @access public
 * @return void
 */
function bones_remove_wp_widget_recent_comments_style() {
   if ( has_filter('wp_head', 'wp_widget_recent_comments_style') ) {
      remove_filter('wp_head', 'wp_widget_recent_comments_style' );
   }
}

/**
 * bones_remove_recent_comments_style 
 *
 * remove injected CSS from recent comments widget
 *
 * @access public
 * @return void
 */
function bones_remove_recent_comments_style() {
    global $wp_widget_factory;
    if (isset($wp_widget_factory->widgets['WP_Widget_Recent_Comments'])) {
        remove_action('wp_head', array($wp_widget_factory->widgets['WP_Widget_Recent_Comments'], 'recent_comments_style'));
    }
}

/**
 * bones_scripts_and_styles 
 *
 * loading modernizr, jquery, styles, and scripts
 *
 * @access public
 * @return void
 */
function bones_scripts_and_styles() {
    if (!is_admin()) {
        // script version. helps to clear out old styles on browser cache when updating
        $ver = WEBPM_VERSION;
        $is_front_page = is_front_page();

        // register main stylesheets
        wp_register_style( 'bones-bootstrap', get_stylesheet_directory_uri() . '/css/bootstrap.css', array(), $ver, 'all' );
        wp_register_style( 'bones-responsive', get_stylesheet_directory_uri() . '/css/responsive.css', array(), $ver, 'all' );
        wp_register_style( 'bones-style', get_stylesheet_directory_uri() . '/style.css', array(), $ver, 'all' );

        // enqueue main stylesheets
        wp_enqueue_style( 'bones-bootstrap' );
        if ( of_get_option( 'responsive_website' ) )
            wp_enqueue_style( 'bones-responsive' );
        wp_enqueue_style( 'bones-style' );

        // comment reply script for threaded comments
        if ( is_singular() AND comments_open() AND (get_option('thread_comments') == 1)) {
          wp_enqueue_script( 'comment-reply' );
        }

        //adding scripts file in the footer
        wp_register_script( 'bones-modernizr', get_stylesheet_directory_uri() . '/js/libs/modernizr.custom.min.js', array(), $ver, false );
        /*
         * Use this if you want to load google's jquery file from cdn
         *
         * wp_deregister_script('jquery');
         * wp_register_script( 'jquery', '//ajax.googleapis.com/ajax/libs/jquery/1.8.3/jquery.min.js', array(), $ver, false );
         **/
        wp_register_script( 'prettify', get_stylesheet_directory_uri() . '/js/libs/prettify.js', array(), $ver, false );
        wp_register_script( 'bootstrap-js', get_stylesheet_directory_uri() . '/js/libs/bootstrap.js', array( 'jquery' ), $ver, true );
        wp_register_script( 'modalgallery-js', get_stylesheet_directory_uri() . '/js/libs/bootstrap.modalGallery.js', array( 'jquery' ), $ver, true );
        wp_register_script( 'bones-js', get_stylesheet_directory_uri() . '/js/scripts.js', array( 'jquery' ), $ver, true );

        // enqueue styles and scripts
        wp_enqueue_script( 'bones-modernizr' );
        wp_enqueue_script( 'jquery' );
        wp_enqueue_script( 'prettify' );
        wp_enqueue_script( 'bootstrap-js' );
        wp_enqueue_script( 'modalgallery-js' );

        $local = array(
            'ajaxurl' => admin_url( 'admin-ajax.php' ),
            'baseurl' => THEME_URI,
            'homeurl' => HOME_URL
        );
        $carousel_interval = get_option( 'webpm_carousel_interval', 0 );
        $local['carouselInterval'] = $carousel_interval;
        $pinit_image_hover = get_option( 'webpm_sharing_pinit_image_hover', 1 );
        $local['pinitImageHover'] = $pinit_image_hover;

        wp_localize_script( 'bones-js', 'Local', $local );
        wp_enqueue_script( 'bones-js' );
    }
}

/**
 * bones_ie_conditional 
 * 
 * adding the conditional wrapper around ie stylesheet
 * source: http://code.garyjones.co.uk/ie-conditional-style-sheets-wordpress/
 *
 * @param mixed $tag 
 * @param mixed $handle 
 * @access public
 * @return void
 */
function bones_ie_conditional( $tag, $handle ) {
    if ( 'bones-ie-only' == $handle )
        $tag = '<!--[if lt IE 9]>' . "\n" . $tag . '<![endif]-->' . "\n";
    return $tag;
}

/**
 * bones_theme_support 
 *
 * Adding WP 3+ Functions & Theme Support
 *
 * @access public
 * @return void
 */
function bones_theme_support() {
    // wp thumbnails (sizes handled in functions.php)
    add_theme_support('post-thumbnails');

    // default thumb size
    set_post_thumbnail_size(200, 200, true);

    // adding post format support
	/*add_theme_support( 'post-formats',
		array(
			'aside',             // title less blurb
			'gallery',           // gallery of images
			'link',              // quick link to other site
			'image',             // an image
			'quote',             // a quick quote
			'status',            // a Facebook like status update
			'video',             // video
			'audio',             // audio
			'chat'               // chat transcript
		)
	);*/

    // wp menus
    add_theme_support( 'menus' );

    // registering wp3+ menus
    register_nav_menus(
        array(
            'main-nav' => __( 'The Main Menu', 'bonestheme' ),    //main nav in header
            //'footer-links' => __( 'Footer Links', 'bonestheme' )  secondary nav in footer
        )
    );
}

/**
 * webpm_send_email 
 *
 * Ajax function to send email without
 * reloading the page.
 * 
 * @access public
 * @return void
 */
function webpm_send_email() {
    // get the submitted parameters
    $error = array();
    $emailSent = false;

    $email_to = get_option('webpm_email_to');
    if ( empty( $email_to ) )
        $email_to = get_option('admin_email');

    if(trim($_POST['name']) === '') {
        $error[] = 'Please enter your name.';
        $hasError = true;
    } else {
        $name = trim($_POST['name']);
    }

    if(trim($_POST['email']) === '')  {
        $error[] = 'Please enter your email address.';
        $hasError = true;
    } else if (!is_email(trim($_POST['email']))) {
        $error[] = 'You entered an invalid email address.';
        $hasError = true;
    } else {
        $email = trim($_POST['email']);
    }

    if(trim($_POST['subject']) === '') {
        $error[] = 'Please enter subject.';
        $hasError = true;
    } else {
        $subject = trim($_POST['subject']);
    }

    if(trim($_POST['message']) === '') {
        $error[] = 'Please enter a message.';
        $hasError = true;
    } else {
        if(function_exists('stripslashes')) {
            $message = stripslashes(trim($_POST['message']));
        } else {
            $message = trim($_POST['message']);
        }
    }

    $error = trim(implode("<br />", $error));

    if(empty($error)) {
        $subject = esc_html($subject);
        $name = esc_html($name);
        $message = esc_html($message);
        $message .= "\n\n\n\nThis message was sent through the contact form via ".get_bloginfo('url');
        $body = "Name: $name \n\nEmail: $email \n\nComments: $message";
        $headers = 'From: '.$name.' <'.$email.'>' . "\r\n" . 'Reply-To: ' . $email;

        wp_mail($email_to, $subject, $body, $headers);
        $emailSent = true;
    }
 
    // generate the response
    $response = json_encode( array( 'success' => (int) $emailSent, 'message' => $error ) );
 
    // response output
    header( "Content-Type: application/json" );
    echo $response;
 
    // IMPORTANT: don't forget to "exit"
    exit;
}

/**
 * webpm_body_class 
 *
 * Add the layout option of the theme selected
 * from theme options.
 * 
 * @param array $classes 
 * @param array $class 
 * @access public
 * @return $classes
 */
function webpm_body_class( $classes, $class ) {
    $classes[] = 'webpm-' . CONTENT_LAYOUT;

    if ( in_array( 'page-template-page-rightsidebar-php', $classes ) )
        $classes[] = 'webpm-sidebar-right';
    else if ( in_array( 'page-template-page-leftsidebar-php', $classes ) )
        $classes[] = 'webpm-sidebar-left';
    else
        $classes[] = 'webpm-sidebar-' . SIDEBAR_POSITION;

    return $classes;
}

/**
 * bones_excerpt_more 
 *
 * This removes the annoying […] to a Read More link 
 *
 * @param mixed $more 
 * @access public
 * @return void
 */
function bones_excerpt_more($more) {
    global $post;
    // edit here if you like
    return '...  <a href="'. get_permalink($post->ID) . '" title="Read '.get_the_title($post->ID).'">Read more &raquo;</a>';
}

/**
 * webpm_content_save_pre 
 *
 * remove extra lines the user inserts in the wordpress
 * text editor. Also removes auto generated spaces
 * 
 * @param mixed $content 
 * @access public
 * @return void
 */
function webpm_content_save_pre($content) {
    //$content = str_replace("&nbsp;", '', $content);
    //$content = preg_replace("/[\r\n]{3,}/", "\r\n\r\n", $content);
    $content = trim($content);

    return $content;
}

/**
 * bones_register_sidebars 
 * 
 * @access public
 * @return void
 */
function bones_register_sidebars() {
    register_sidebar(array(
    	'id' => 'sidebar1',
    	'name' => 'Sidebar 1',
    	'description' => 'The first (primary) sidebar.',
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));
    register_sidebar(array(
    	'id' => 'footer1',
    	'name' => 'Footer Column 1',
    	'description' => 'Footer Column 1',
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));
    register_sidebar(array(
    	'id' => 'footer2',
    	'name' => 'Footer Column 2',
    	'description' => 'Footer Column 2',
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));
    register_sidebar(array(
    	'id' => 'footer3',
    	'name' => 'Footer Column 3',
    	'description' => 'Footer Column 3',
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));
    register_sidebar(array(
    	'id' => 'footer4',
    	'name' => 'Footer Column 4',
    	'description' => 'Footer Column 4',
    	'before_widget' => '<div id="%1$s" class="widget %2$s">',
    	'after_widget' => '</div>',
    	'before_title' => '<h4 class="widgettitle">',
    	'after_title' => '</h4>',
    ));
}

/**
 * options_css_styles 
 *
 * Outputs the selected option panel styles inline into the <head>
 * 
 * @access public
 * @return void
 */
function options_css_styles() {
    $output = '';

    $line_height_increase = 6;
    $fonts = get_options_typography_mixed_fonts();

    // font-family
    if ( $val = of_get_option( 'header_font' ) ) {
        $selector = '#wrapper h1, #wrapper h2, #wrapper h3, #wrapper h4, #wrapper h5, #wrapper h6';
        $output .= $selector . ' {font-family:' . $fonts[$val] . ' !important;}';
    }
    if ( $val = of_get_option( 'text_font' ) ) {
        $selector = '#wrapper, input, button, select, textarea, #webpm-popup-modals, body #wrapper .widget_webpm_pinterest span a';
        $output .= $selector . ' {font-family:' . $fonts[$val] . ' !important;}';
    }
    if ( $val = of_get_option( 'widget_header_font' ) ) {
        $selector = '#wrapper .widgettitle';
        $output .= $selector . ' {font-family:' . $fonts[$val] . ' !important;}';
    }
    if ( $val = of_get_option( 'date_font' ) ) {
        $selector = '#wrapper .date-header';
        $output .= $selector . ' {font-family:' . $fonts[$val] . ' !important;}';
    }
    if ( $val = of_get_option( 'menu_font' ) ) {
        $selector = '#navbar .nav li a';
        $output .= $selector . ' {font-family:' . $fonts[$val] . ' !important;}';
    }
    // font size
    if ( $val = of_get_option( 'menu_font_size' ) ) {
        $selector = '#navbar, #navbar li, #navbar li a';
        $output .= $selector . ' {font-size:' . $val . 'px;}';
    }
    if ( $val = of_get_option( 'text_font_size' ) ) {
        $selector = 'html body, body li, body ol, .carousel-caption p, body label, body input, body button, body select, body textarea';
        $output .= $selector . ' {font-size:' . $val . 'px;}';

        $selector = 'body #wrapper .widget_webpm_pinterest span a';
        $output .= $selector . ' {font-size:' . $val . 'px !important;}';

        $val += $line_height_increase;
        $selector = 'html body, body li, body ol, .carousel-caption p, body label, body input, body button, body select, body textarea';
        $output .= $selector . ' {line-height:' . $val . 'px;}';
    }
    if ( $val = of_get_option( 'date_font_size' ) ) {
        $selector = '#wrapper .date-header';
        $output .= $selector . ' {font-size:' . $val . 'px;}';
        $val += $line_height_increase;
        $selector = '#wrapper .date-header';
        $output .= $selector . ' {line-height:' . $val . 'px;}';
    }
    if ( $val = of_get_option( 'footer_font_size' ) ) {
        $selector = '#wrapper #footer';
        $output .= $selector . ' {font-size:' . $val . 'px;}';
        $val += $line_height_increase;
        $selector = '#wrapper #footer';
        $output .= $selector . ' {line-height:' . $val . 'px;}';
    }
    if ( $val = of_get_option( 'header_font_size' ) ) {
        $selector = '#wrapper h1';
        $lh = $val + $line_height_increase;
        $output .= $selector . ' {font-size:' . $val . 'px;line-height:' . $lh .'px;}';

        $val -= 2;
        $selector = '#wrapper h2';
        $lh = $val + $line_height_increase;
        $output .= $selector . ' {font-size:' . $val . 'px;line-height:' . $lh .'px;}';

        $val -= 4;
        $selector = '#wrapper h3';
        $lh = $val + $line_height_increase;
        $output .= $selector . ' {font-size:' . $val . 'px;line-height:' . $lh .'px;}';

        $val -= 2;
        $selector = '#wrapper h4';
        $lh = $val + $line_height_increase;
        $output .= $selector . ' {font-size:' . $val . 'px;line-height:' . $lh .'px;}';

        $val -= 2;
        $selector = '#wrapper h5';
        $lh = $val + $line_height_increase;
        $output .= $selector . ' {font-size:' . $val . 'px;line-height:' . $lh .'px;}';

        $val -= 2;
        $selector = '#wrapper h6';
        $lh = $val + $line_height_increase;
        $output .= $selector . ' {font-size:' . $val . 'px;line-height:' . $lh .'px;}';
    }
    if ( $val = of_get_option( 'widget_font_size' ) ) {
        $selector = '#wrapper .widgettitle';
        $lh = $val + $line_height_increase;
        $output .= $selector . ' {font-size:' . $val . 'px;line-height:' . $lh .'px;}';
    }
    if ( $val = of_get_option( 'image_caption_font_size' ) ) {
        $selector = '#wrapper .wp-caption-text';
        $lh = $val + $line_height_increase;
        $output .= $selector . ' {font-size:' . $val . 'px;line-height:' . $lh .'px;}';
    }
    // color
    if ( $val = of_get_option( 'header_font_color' ) ) {
        $selector = '';
        $selector .= '#wrapper h1, #wrapper h1 a, #wrapper h1 a:hover, #wrapper h1 a:active, ';
        $selector .= '#wrapper h2, #wrapper h2 a, #wrapper h2 a:hover, #wrapper h2 a:active, ';
        $selector .= '#wrapper h3, #wrapper h3 a, #wrapper h3 a:hover, #wrapper h3 a:active, ';
        $selector .= '#wrapper h4, #wrapper h4 a, #wrapper h4 a:hover, #wrapper h4 a:active, ';
        $selector .= '#wrapper h5, #wrapper h5 a, #wrapper h5 a:hover, #wrapper h5 a:active, ';
        $selector .= '#wrapper h6, #wrapper h6 a, #wrapper h6 a:hover, #wrapper h6 a:active ';
        $output .= $selector . ' {color:' . $val . ';}';
    }
    if ( $val = of_get_option( 'text_font_color' ) ) {
        $selector = 'html body, #wrapper legend, #wrapper small, #wrapper select, #wrapper textarea, #wrapper input, #wrapper .uneditable-input';
        $output .= $selector . ' {color:' . $val . ';}';
    }
    if ( $val = of_get_option( 'menu_font_color' ) ) {
        $selector = '#navbar .nav li a';
        $output .= $selector . ' {color:' . $val . ';}';
    }
    if ( $val = of_get_option( 'footer_font_color' ) ) {
        $selector = '#wrapper #footer';
        $output .= $selector . ' {color:' . $val . ';}';
    }
    if ( $val = of_get_option( 'date_font_color' ) ) {
        $selector = '#wrapper .date-header';
        $output .= $selector . ' {color:' . $val . ';}';
    }
    if ( $val = of_get_option( 'widget_font_color' ) ) {
        $selector = '#wrapper .widgettitle';
        $output .= $selector . ' {color:' . $val . ';}';
    }
    if ( $val = of_get_option( 'menu_font_hover_color' ) ) {
        $selector = '#navbar .nav li.active > a, #navbar .nav li a:hover';
        $output .= $selector . ' {color:' . $val . ';}';
    }
    if ( $val = of_get_option( 'link_font_color' ) ) {
        $output .= '#wrapper a {color:'.$val.';}';
        $selector = 'body #wrapper .widget_webpm_pinterest span a';
        $output .= $selector . ' {color:'.$val.' !important;}';
    }
    if ( $val = of_get_option( 'link_font_hover_color' ) ) {
        $selector = '#wrapper a:hover, #wrapper a:active';
        $output .= $selector . ' {color:'.$val.';}';
        $selector = 'body #wrapper .widget_webpm_pinterest span a:hover, body #wrapper .widget_webpm_pinterest span a:active';
        $output .= $selector . ' {color:'.$val.' !important;}';
    }
    if ( $val = of_get_option( 'carousel_caption_color' ) ) {
        $selector = '#wrapper .carousel-caption h4, #wrapper .carousel-caption p';
        $output .= $selector . ' {color:'.$val.' !important;}';
    }
    // buttons
    $selector = '#wrapper input[type="submit"], #wrapper button, #wrapper .btn';
    if ( $val = of_get_option( 'button_background_color' ) ) {
        $output .= $selector . ' {background-color:' . $val . ';}';
    }
    if ( $val = of_get_option( 'button_text_color' ) ) {
        $output .= $selector . ' {color: ' . $val . ';}';
    }
    if ( $val = of_get_option( 'button_border_color' ) ) {
        $output .= $selector . ' {border-color: ' . $val . ';}';
    }
    $selector =  '#wrapper input[type="submit"]:hover, #wrapper button:hover, #wrapper .btn:hover';
    $selector .= ', #wrapper input[type="submit"]:active, #wrapper button:active, #wrapper .btn:active';
    if ( $val = of_get_option( 'button_background_hover_color' ) ) {
        $output .= $selector . ' {background-color:' . $val . ';}';
    }
    if ( $val = of_get_option( 'button_text_hover_color' ) ) {
        $output .= $selector . ' {color: ' . $val . ';}';
    }
    if ( $val = of_get_option( 'button_border_hover_color' ) ) {
        $output .= $selector . ' {border-color: ' . $val . ';}';
    }
    $selector = '';
    // background
    if ( $val = of_get_option( 'body_background' ) ) {
        $selector = 'body';
        $output .= options_background_styles( $val , $selector);
        if ( empty($val['image']) )
            $output .= $selector . ' {background-image:none;}';
        if ( empty($val['color']) )
            $output .= $selector . ' {background-color:transparent;}';
    }
    if ( $val = of_get_option( 'banner_background' ) ) {
        $selector = '#wrapper .header-image-wrapper';
        $output .= options_background_styles( $val , $selector );
        if ( empty($val['image']) )
            $output .= $selector . ' {background-image:none;}';
        if ( empty($val['color']) )
            $output .= $selector . ' {background-color:transparent;}';
    }
    if ( $val = of_get_option( 'widget_background' ) ) {
        $selector = '#wrapper .sidebar .widgettitle';
        $output .= options_background_styles( $val , $selector );
        if ( empty($val['image']) )
            $output .= $selector . ' {background-image:none;}';
        if ( empty($val['color']) )
            $output .= $selector . ' {background-color:transparent;}';
    }
    if ( $val = of_get_option( 'byline_background' ) ) {
        $selector = '#wrapper .byline';
        $output .= options_background_styles( $val , $selector );
        if ( empty($val['image']) )
            $output .= $selector . ' {background-image:none;}';
        if ( empty($val['color']) )
            $output .= $selector . ' {background-color:transparent;}';
    }
    if ( $val = of_get_option( 'menu_background_color' ) ) {
        $selector = '#navbar .navbar-inner, #navbar .sub-menu, #navbar .sub-menu>li>a:hover, #navbar .sub-menu>li>a:focus, #navbar .sub-menu>li.current_page_item>a, #navbar .sub-menu>li.current_page_item>a:hover, #navbar .sub-menu>li.current_page_item>a:focus, #navbar .children, #navbar .children>li>a:hover, #navbar .children>li>a:focus, #navbar .children>li.current_page_item>a, #navbar .children>li.current_page_item>a:hover, #navbar .children>li.current_page_item>a:focus';
        $output .= $selector . ' {background-color:' . $val . ';}';
    }
    /*if ( $val = of_get_option( 'sidebar_background_color' ) ) {
        $selector = '#wrapper .sidebar';
        $output .= $selector . ' {background-color:' . $val . ';}';
    }*/
    if ( $val = of_get_option( 'menu_button_color' ) ) {
        $selector = '#navbar .btn-navbar';
        $output .= $selector . ' {background-color:' . $val . ';}';
    }
    if ( $val = of_get_option( 'menu_button_hover_color' ) ) {
        $selector = '#navbar .btn-navbar:hover';
        $output .= $selector . ' {background-color:' . $val . ';}';
    }
    if ( $val = of_get_option( 'menu_button_accent_color' ) ) {
        $selector = '#wrapper #navbar .btn-navbar, #wrapper #navbar .btn-navbar .icon-bar';
        $output .= $selector . ' {border-color:' . $val . ';}';
        $selector = '#wrapper #navbar .btn-navbar .icon-bar';
        $output .= $selector . ' {background-color:' . $val . ';}';
    }
    // misc
    if ( $val = of_get_option( 'menu_text_transform' ) ) {
        $selector = '#navbar .nav li a';
        $output .= $selector . ' {text-transform:' . $val . ';}';
    }
    if ( $val = of_get_option( 'date_text_transform' ) ) {
        $selector = '#wrapper .date-header';
        $output .= $selector . ' {text-transform:' . $val . ';}';
    }
    if ( $val = of_get_option( 'header_text_transform' ) ) {
        $selector = '#wrapper h1, #wrapper h2, #wrapper h3, #wrapper h4, #wrapper h5, #wrapper h6';
        $output .= $selector . ' {text-transform:' . $val . ';}';
    }
    if ( $val = of_get_option( 'widget_text_transform' ) ) {
        $selector = '#wrapper .widgettitle';
        $output .= $selector . ' {text-transform:' . $val . ';}';
    }
    if ( $val = of_get_option( 'logo_top_offset' ) ) {
        $selector = '#header-image';
        $output .= $selector . ' {margin-top:' . $val . 'px;}';
    }
    else {
        $selector = '#header-image';
        $output .= $selector . ' {margin-top:0px;}';
    }
    if ( $val = of_get_option( 'logo_bottom_offset' ) ) {
        $selector = '#header-image';
        $output .= $selector . ' {margin-bottom:' . $val . 'px;}';
    }
    else {
        $selector = '#header-image';
        $output .= $selector . ' {margin-bottom:0px;}';
    }
    if ( $val = of_get_option( 'logo_side_padding' ) ) {
        $selector = '#wrapper .header-image-wrapper a';
        $output .= $selector . ' {padding-left:' . $val . 'px;padding-right:' . $val . 'px;}';
    }
    else {
        $selector = '#wrapper .header-image-wrapper a';
        $output .= $selector . ' {padding-left:0px;padding-right:0px;}';
    }
    // navbar
    if ( $val = of_get_option( 'menu_bar_height' ) ) {
        $menu_bar_height = (int) $val;

        $val = of_get_option( 'menu_text_padding_top', 0 );
        $padding_top = (int) $val;

        $val = of_get_option( 'menu_text_padding_bottom', 0 );
        $padding_bottom = (int) $val;

        $menu_bar_height = $menu_bar_height - $padding_top - $padding_bottom;

        $selector = '#navbar .nav li a';
        $output .= $selector . ' {line-height:' . $menu_bar_height . 'px;padding-top:' . $padding_top .'px;padding-bottom:' . $padding_bottom . 'px;}';

        if ( $val = of_get_option( 'dropdown_height' ) ) {
            $dropdown_height = (int) $val;

            $dropdown_height = $dropdown_height - $padding_top - $padding_bottom;

            $selector = '#navbar .nav .sub-menu>li>a, #navbar .nav .children>li>a';
            $output .= $selector . ' {line-height:' . $dropdown_height . 'px;padding-top:' . $padding_top .'px;padding-bottom:' . $padding_bottom . 'px;}';
        }
    }
    // css
    if ( $val = of_get_option( 'custom_css' ) ) {
        $val = preg_replace( "/\s+/", " ", $val );
        $output .= trim( $val );
    }

    // display inline css
    if ( $output != '' ) {
        $output = "\n<style type=\"text/css\" media=\"screen\">\n" . $output . "\n</style>\n";
        echo $output;
    }
}

/**
 * options_typography_get_os_fonts 
 *
 * This also Returns an array of system fonts (Web Safe Fonts). 
 * This is typically called from options.php. Feel free to edit 
 * this, update the font fallbacks, etc.
 * 
 * @access public
 * @return void
 */
function options_typography_get_os_fonts() {
	$os_faces = array(
		'Arial' => 'Arial, sans-serif', // Web Safe Font
		'Cambria' => 'Cambria, Georgia, serif', // Web Safe Font
		'Courier+New' => '"Courier New", sans-serif', // Web Safe Font
		'Garamond' => 'Garamond, "Hoefler Text", Times New Roman, Times, serif', // Web Safe Font
		'Georgia' => 'Georgia, serif', // Web Safe Font
		'Helvetica+Neue' => '"Helvetica Neue", Helvetica, sans-serif', // Web Safe Font
		'Tahoma' => 'Tahoma, Geneva, sans-serif' // Web Safe Font
	);
	return $os_faces;
}

/**
 * options_typography_get_google_fonts 
 *
 * Returns a select list of Google fonts
 * Feel free to edit this, update the fallbacks, etc.
 * 
 * @access public
 * @return void
 */
function options_typography_get_google_fonts() {
	// Google Font Defaults
	// The key is inserted in the google css decleartion
	// the value is used to declare the font family in your css
	$google_faces = array(
		'Alice' => 'Alice, serif',
		'Allura'=> 'Allura, cursive',
		'Amatic+SC'=> '"Amatic SC", cursive',
		'Anonymous+Pro' => '"Anonymous Pro", sans-serif',
		'Antic' => 'Antic, sans-serif',
		'Antic+Slab' => '"Antic Slab", serif',
		'Arvo' => 'Arvo, serif',
		'Bad+Script' => '"Bad Script", cursive',
		'Belleza' => 'Belleza, sans-serif',
		'Bree+Sefif' => '"Bree Serif", serif',
		'Buda:300' => 'Buda, cursive',
		'Cabin' => 'Cabin, sans-serif',
		'Cabin+Condensed' => '"Cabin Condensed", sans-serif',
		'Cabin+Sketch' => '"Cabin Sketch", cursive',
		'Cambo' => 'Cambo, serif',
		'Cardo' => 'Cardo, serif',
		'Cedarville+Cursive'=> '"Cedarville Cursive", cursive',
		'Clicker+Script' => '"Clicker Script", cursive',
		'Comfortaa' => 'Comfortaa, cursive',
		'Coming+Soon'=> '"Coming Soon", cursive',
		'Cookie'=> 'Cookie, cursive',
		'Copse' => 'Copse, sans-serif',
		'Courgette' => 'Courgette, cursive',
		'Cousine' => 'Cousine, sans-serif',
		'Crushed' => 'Crushed, cursive',
		'Cutive' => 'Cutive, serif',
		'Cutive+Mono'=> '"Cutive Mono", serif',
		'Dancing+Script' => '"Dancing Script", cursive',
		'Dawning+of+a+New+Day'=> '"Dawning of a New Day", cursive',
		'Droid+Sans' => '"Droid Sans", sans-serif',
		'Droid+Serif' => '"Droid Serif", serif',
		'Euphoria+Script' => '"Euphoria Script", cursive',
		'Federo' => 'Federo, sans-serif',
		'Flamenco' => 'Flamenco, cursive',
		'Fresca' => 'Fresca, sans-serif',
		'Gabriela' => 'Gabriela, serif',
		'Handlee' => 'Handlee, cursive',
		'Homemade+Apple' => '"Homemade Apple", cursive',
		'Inconsolata' => 'Inconsolata, sans-serif',
		'Indie+Flower' => '"Indie Flower", cursive',
		'Josefin+Sans'=> '"Josefin Sans", sans-serif',
		'Josefin+Slab'=> '"Josefin Slab", serif',
		'Julee' => 'Julee, cursive',
		'Jura'=> 'Jura, sans-serif',
		'La+Belle+Aurore'=> '"La Belle Aurore", cursive',
		'Lobster' => 'Lobster, cursive',
		'Lobster+Two' => '"Lobster Two", cursive',
		'Londrina+Outline' => '"Londrina Outline", cursive',
		'Lora'=> 'Lora, serif',
		'Loved+by+the+King' => '"Loved By The King", cursive',
		'Marck+Script' => '"Marck Script", cursive',
		'Mate' => 'Mate, serif',
		'Meddon' => 'Meddon, cursive',
		'Merriweather' => 'Merriweather, serif',
		'Merriweather+Sans' => '"Merriweather Sans", sans-serif',
		'Milonga' => 'Milonga, cursive',
		'Miniver'=> 'Miniver, cursive',
		'Neucha'=> 'Neucha, cursive',
		'Neuton' => 'Neuton, serif',
		'Niconne' => 'Niconne, cursive',
		'Nixie+One'=> '"Nixie One", cursive',
		'Nobile' => 'Nobile, sans-serif',
		'Nothing+You+Could+Do' => '"Nothing You Could Do", cursive',
		'Open+Sans' => '"Open Sans", sans-serif',
		'Open+Sans+Condensed:300' => '"Open Sans Condensed", sans-serif',
		'Oswald' => 'Oswald, sans-serif',
		'Overlock'=> 'Overlock, cursive',
		'Oxygen' => 'Oxygen, sans-serif',
		'Pacifico' => 'Pacifico, cursive',
		'Paprika' => 'Paprika, cursive',
		'Parisienne'=> 'Parisienne, cursive',
		'Patrick+Hand' => '"Patrick Hand", cursive',
		'Patrick+Hand+SC' => '"Patrick Hand SC", cursive',
		'Petit+Formal+Script'=> '"Petit Formal Script", cursive',
		'Pinyon+Script' => '"Pinyon Script", cursive',
		'Pompiere'=> 'Pompiere, cursive',
		'Poiret+One'=>'"Poiret One", cursive',
		'PT+Sans' => '"PT Sans", sans-serif',
		'PT+Sans+Narrow'=> '"PT Sans Narrow", sans-serif',
		'Quattrocento' => 'Quattrocento, serif',
		'Quicksand' => 'Quicksand, sans-serif',
		'Raleway' => 'Raleway, cursive',
		'Raleway+Dots' => '"Raleway Dots", cursive',
		'Rancho' => 'Rancho, cursive',
		'Rochester'=> 'Rochester, cursive',
		'Rokkit' => 'Rokkitt, serif',
		'Rouge+Script' => '"Rouge Script", cursive',
		'Ruluko' => 'Ruluko, sans-serif',
		'Sacramento'=> 'Sacramento, cursive',
		'Sail'=> 'Sail, cursive',
		'Satisfy' => 'Satisfy, cursive',
		'Snippet' => 'Snippet, sans-serif',
		'Sofia' => 'Sofia, cursive',
		'Sorts+Mill+Goudy' => '"Sorts Mill Goudy", serif',
		'Special+Elite' => '"Special Elite", cursive',
		'Sue+Ellen+San+Francisco'=> '"Sue Ellen Francisco", cursive',
		'Syncopate' => 'Syncopate, sans-serif',
		'The+Girl+Next+Door'=> '"The Girl Next Door", cursive',
		'Unkempt'=> 'Unkempt, cursive',
		'Ubuntu' => 'Ubuntu, sans-serif',
		'Ubuntu+Condensed' => '"Ubuntu Condensed", sans-serif',
		'Volkhov'=> 'Volkhov, serif',
		'Yanone+Kaffeesatz' => '"Yanone Kaffeesatz", sans-serif',
		'Vast+Shadow'=> '"Vast Shadow", cursive',
		'Waiting+for+the+Sunrise' => '"Waiting For The Sunrise", cursive',
		'Walter+Turncoat' => '"Walter Turncoat", cursive',
		'Zeyada' => 'Zeyada, cursive'
	);
	return $google_faces;
}

/**
 * get_options_typography_mixed_fonts 
 *
 * Merge OS fonts and Google Web Fonts
 * 
 * @access public
 * @return void
 */
function get_options_typography_mixed_fonts() {
    $typography_mixed_fonts = array_merge( options_typography_get_os_fonts(), options_typography_get_google_fonts() );
    ksort($typography_mixed_fonts);

    return $typography_mixed_fonts;
}
    

/**
 * options_background_styles 
 * 
 * Returns a background style in a format that can be outputted as inline CSS
 *
 * @param array $option array returned from calling of_get_option()
 * @param mixed $selectors css selector to apply this style rule to
 * @access public
 * @return void
 */
function options_background_styles($option, $selectors) {
	$rules = '';
	if ( !empty( $option['image'] ) )
		$rules .= 'background-image:url("'. $option['image'] .'");';
	if ( !empty( $option['color'] ) )
		$rules .= 'background-color:'.$option['color'].';';
	if ( !empty( $option['repeat'] ) )
		$rules .= 'background-repeat:'.$option['repeat'].';';
	if ( !empty( $option['position'] ) )
		$rules .= 'background-position:'.$option['position'].';';
	if ( !empty( $option['attachment'] ) )
		$rules .= 'background-attachment:'.$option['attachment'].';';

	$output = '';
	if ( !empty($rules) ) {
		$output .= $selectors . ' {'.$rules.'}';
		//$output .= "\n";
	}
	return $output;
}

/**
 * options_typography_font_styles
 * 
 * Returns a typography style in a format that can be outputted as inline CSS
 *
 * @param array $option array returned from calling of_get_option()
 * @param mixed $selectors css selector to apply this style rule to
 * @access public
 * @return void
 */
function options_typography_font_styles($option, $selectors, $important = false) {
    global $typography_mixed_fonts;

    $output = $selectors . ' {';

    $important = $important ? ' !important' : '';


	if ( !empty( $option['color'] ) )
        $output .= ' color:' . $option['color'] . $important . ';';
	if ( !empty( $option['face'] ) ) {
        if ( array_key_exists( $option['face'], $typography_mixed_fonts ) )
            $output .= 'font-family:' . $typography_mixed_fonts[$option['face']] . $important . ';';
    }
	if ( !empty( $option['style'] ) )
        $output .= 'font-weight:' . $option['style'] . $important . ';';
	if ( !empty( $option['size'] ) )
        $output .= 'font-size:' . $option['size'] . $important . ';';

    $output .= '}';
    //$output .= "\n";
    return $output;
}

/**
 * options_typography_google_fonts 
 *
 * Checks font options to see if a Google font is selected.
 * If so, options_typography_enqueue_google_font is called to enqueue the font.
 * Ensures that each Google font is only enqueued once.
 * 
 * @access public
 * @return void
 */
if ( !function_exists( 'options_typography_google_fonts' ) ) {
	function options_typography_google_fonts() {
		if ( !is_admin() ) {
			$all_google_fonts = array_keys( options_typography_get_google_fonts() );
			// Define all the options that possibly have a unique Google font
			$text_font = of_get_option('text_font');
			$menu_font = of_get_option('menu_font');
			$header_font = of_get_option('header_font');
			$widget_header_font = of_get_option('widget_header_font');
			$date_font = of_get_option('date_font');
			// Get the font face for each option and put it in an array
			$selected_fonts = array(
                $text_font,
                $menu_font,
				$header_font,
                $widget_header_font,
                $date_font
            );
			// Remove any duplicates in the list
			$selected_fonts = array_unique($selected_fonts);
			// Check each of the unique fonts against the defined Google fonts
			// If it is a Google font, go ahead and call the function to enqueue it
            $fonts = array();
			foreach ( $selected_fonts as $font ) {
				if ( in_array( $font, $all_google_fonts ) ) {
                    $fonts[] = $font;
				}
			}
            
            if ( !empty( $fonts ) ) {
                $fonts = implode( $fonts, '|' );
                options_typography_enqueue_google_font($fonts);
            }
		}
	}
}

/**
 * options_typography_enqueue_google_font 
 *
 * Enqueues the Google $font that is passed
 * 
 * @param mixed $font the google font family name
 * @access public
 * @return void
 */
function options_typography_enqueue_google_font($fonts) {
	wp_enqueue_style( "options_typography_$fonts", "http://fonts.googleapis.com/css?family=$fonts", false, null, 'all' );
}

/**
 * bones_filter_the_content 
 * 
 * @param mixed $content 
 * @access public
 * @return void
 */
function bones_filter_the_content($content) {
    return $content;
}

/**
 * webpm_testing_notice 
 * 
 * @access public
 * @return void
 */
function webpm_testing_notice() {
    echo '<div class="testing-notice">Testing Site</div>';
}

/**
 * webpm_helper_modal_map 
 * 
 * @access public
 * @return void
 */
function webpm_helper_modal_map() {
	$map = '';
	$geocode = trim( of_get_option( 'geocode' ) );

	if ( !empty( $geocode ) ) {
		$map .= '<div id="google-map" class="modal fade hide">';
			$map .= '<div class="modal-header">';
				$map .= '<h3>Map <a class="close" data-dismiss="modal">×</a></h3>';
			$map .= '</div>';
			$map .= '<div class="modal-body" style="text-align: center;height:400px;">';
				$map .= '<div id="map_canvas" style="width:100%;height:100%;"><i class="showcase icon-spinner icon-spin icon-2x"></i></div>';
			$map .= '</div>';
			$map .= '<div class="modal-footer">';
				$map .= '<button class="btn" data-dismiss="modal">Close</button>';
			$map .= '</div>';
		$map .= '</div>';
	}

	echo $map;
}

/**
 * webpm_social_url 
 *
 * filter social url. For example, we want to add
 * mailto: to an email address.
 * 
 * @access public
 * @return void
 */
function webpm_social_url( $name, $social_url ) {
    switch ( $name ) {
        case 'email' :
            // some users may have already inserted mailto:, so let's remove it.
            $social_url = str_replace( 'mailto:', '', $social_url );
            $social_url = 'mailto:'.$social_url;
            break;
    }

    return $social_url;
}

/**
 * webpm_excerpt_length 
 * 
 * @param mixed $length 
 * @access public
 * @return void
 */
function webpm_excerpt_length( $length ) {
    return 80;
}

?>
