<?php
/******************************************************************
Author: Chris Baldelomar
URL: http://webplantmedia.com

All widget code should go here.
******************************************************************/

function bones_widgets_init() {
	// Register social icons widget version 2
    register_widget('WebPM_Social_Icons_Widget_v2');

	// Register about me widget
    register_widget('WebPM_About_Me_Widget');

    // uses official Pinterest javascript widget
    register_widget('WebPM_Pinterest_Widget');

    // image widget
	register_widget( 'Bootstrap_Image_Widget' );
}
add_action('widgets_init', 'bones_widgets_init');

/**
 * WebPM_Social_Icons_Widget_v2 
 *
 * This displays a sidebar widget of social media icons.
 * 
 * @uses WP
 * @uses _Widget
 */
class WebPM_Social_Icons_Widget_v2 extends WP_Widget {
    private $social = array(
        'facebook',
        'google_plus',
        'twitter',
        'pinterest',
        'instagram',
        'bloglovin',
        'flickr',
        'rss',
        'email',
        'custom1',
        'custom2',
        'custom3',
        'custom4',
        'custom5'
    );

    function __construct() {
        $widget_ops = array( 'description' => __('Add your social icons to your sidebar.') );
        parent::__construct( 'webpm_social_icons_v2', __('Social Icons'), $widget_ops );
    }

    function widget($args, $instance) {

        $instance['title'] = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

        echo $args['before_widget'];

        if ( !empty($instance['title']) )
            echo $args['before_title'] . $instance['title'] . $args['after_title'];

        // set class with the number of columns the user selected
        $columns = (int) $instance['columns'];
        if ( empty($columns) ) {
            $columns = 3;
        }
        $class = ' columns-'.$columns;

        // generate html structure. using bootstrap .thumbnails
        // http://twitter.github.com/bootstrap/components.html#thumbnails
        // wordpress.less has a few overrides for display in the sidebar
        $html = '<div class="row-fluid">';
            $html .= '<ul class="thumbnails'.$class.'">';
                $i = 0;
                foreach ($this->social as $name) {
                    $clear = ( $i % $columns == 0 ) ? ' clear-left' : '';

                    if ( ( $social_url = of_get_option( $name.'_url' ) ) && ( $icon_url = of_get_option( $name.'_icon' ) ) ) {
                        $social_url = apply_filters( 'webpm_social_url', $name, $social_url );

                        $html .= '<li class="social-icon'.$clear.'">';
                            $html .='<a href="'.$social_url.'" class="thumbnail">';
                                $html .= '<img src="'.$icon_url.'">';
                            $html .= '</a>';
                        $html .= '</li>';
                        $i++;
                    }
                }
            $html .= '</ul>';
        $html .= '</div>';

        echo $html;

        echo $args['after_widget'];
    }

    function update( $new_instance, $old_instance ) {
        $instance['title'] = strip_tags( stripslashes($new_instance['title']) );
        $instance['columns'] = (int) $new_instance['columns'];
        return $instance;
    }

    function form( $instance ) {
        $title = isset( $instance['title'] ) ? $instance['title'] : 'Follow Me!';
        $columns = isset( $instance['columns'] ) ? (int) $instance['columns'] : 3;
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:') ?></label>
            <input type="text" class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $title; ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('columns'); ?>"><?php _e('Number of Columns:'); ?></label>
            <select id="<?php echo $this->get_field_id('columns'); ?>" name="<?php echo $this->get_field_name('columns'); ?>">
                <option value="1"<?php selected( $columns, '1' ); ?>>1</option>';
                <option value="2"<?php selected( $columns, '2' ); ?>>2</option>';
                <option value="3"<?php selected( $columns, '3' ); ?>>3</option>';
                <option value="4"<?php selected( $columns, '4' ); ?>>4</option>';
                <option value="5"<?php selected( $columns, '5' ); ?>>5</option>';
            </select>
        </p>
        <?php
    }
}

/**
 * WebPM_Pinterest_Widget 
 *
 * My own widget class for pinterest. Works well, execpt for
 * one small display bug in footer.
 * 
 * @uses WP
 * @uses _Widget
 */
class WebPM_Pinterest_Widget extends WP_Widget {
    function __construct() {
        $widget_ops = array( 'description' => __('Add your latest pins form Pinterest to your sidebar.') );
        parent::__construct( 'webpm_pinterest', __('Official Pinterest Widget'), $widget_ops );
    }

    function widget($args, $instance) {
        $instance['title'] = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

        echo $args['before_widget'];

        if ( !empty($instance['title']) )
            echo $args['before_title'] . $instance['title'] . $args['after_title'];

        if ( !empty( $instance['username'] ) ) {
            echo '<a data-pin-do="embedUser" href="http://pinterest.com/'.$instance['username'].'/" data-pin-scale-width="98" data-pin-scale-height="400" data-pin-board-width="200"></a>';
        }

        echo $args['after_widget'];
    }

    function update( $new_instance, $old_instance ) {
        $instance['title'] = strip_tags( stripslashes($new_instance['title']) );
        $instance['username'] = strip_tags( stripslashes($new_instance['username']) );
        return $instance;
    }

    function form( $instance ) {
        $title = isset( $instance['title'] ) ? $instance['title'] : 'Latest Pins!';
        $username = isset( $instance['username'] ) ? $instance['username'] : '';
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:') ?></label>
            <input type="text" class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $title; ?>" />
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('username'); ?>"><?php _e('Pinterest Username:') ?></label>
            <input type="text" class="widefat" id="<?php echo $this->get_field_id('username'); ?>" name="<?php echo $this->get_field_name('username'); ?>" value="<?php echo $username; ?>" />
        </p>
        <?php
    }
}

/**
 * WebPM_About_Me_Widget 
 *
 * Beginning structure for about me
 * image. All I really need now is a good clean
 * way to upload image. At the moment, A user
 * has to upload an image through theme options.
 * 
 * I would be better if they could upload the image
 * through this widget.
 * 
 * @uses WP
 * @uses _Widget
 */
class WebPM_About_Me_Widget extends WP_Widget {
    function __construct() {
        $widget_ops = array( 'description' => __('Add and customize your "About Me" information.') );
        parent::__construct( 'webpm_about_me', __('About Me'), $widget_ops );
    }

    function widget($args, $instance) {
        $instance['title'] = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

        echo $args['before_widget'];

        if ( !empty($instance['title']) )
            echo $args['before_title'] . $instance['title'] . $args['after_title'];

        $class = !empty( $instance['style'] ) ? $instance['style'] : 'none';


        $url = !empty( $instance['url'] ) ? esc_url( $instance['url'] ) : '';

        if ( $about_me = of_get_option( 'about_me_image' ) ) {
            if ( !empty( $url ) )
                echo '<a class="image-hover" href="'.$url.'">';

            echo '<img class="img-'.$class.'" src="'.$about_me.'" />';

            if ( !empty( $url ) )
                echo '</a>';
        }

        if ( !empty( $instance['description'] ) )
            echo '<p class="sidebar-caption">'.esc_html( $instance['description'] ).'</p>';

        echo $args['after_widget'];
    }

    function update( $new_instance, $old_instance ) {
        $instance['title'] = strip_tags( stripslashes($new_instance['title']) );
        $instance['description'] = strip_tags( stripslashes($new_instance['description']) );
        $instance['style'] = strip_tags( $new_instance['style'] );
        $instance['url'] = esc_url_raw( $new_instance['url'] );
        return $instance;
    }

    function form( $instance ) {
        $title = isset( $instance['title'] ) ? $instance['title'] : 'About Me!';
        $description = isset( $instance['description'] ) ? $instance['description'] : '';
        $description = esc_textarea($description);
        $style = isset( $instance['style'] ) ? $instance['style'] : 'none';
        $url = isset( $instance['url'] ) ? $instance['url'] : '';
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:') ?></label>
            <input type="text" class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo $title; ?>" />
        </p>
        <p>
            <?php if ( $about_me = of_get_option( 'about_me_image' ) ) : ?>
                <img src="<?php echo $about_me; ?>" />
            <?php else : ?>
                Please go to <span style="background-color:#1e6a8d;color:white;padding:0 5px;">Appearences => Theme&nbsp;Options => Sidebar</span> and upload your 'About Me' image.
            <?php endif; ?>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('description'); ?>"><?php _e('Description:') ?></label>
            <textarea class="widefat" rows="4" cols="20" id="<?php echo $this->get_field_id('description'); ?>" name="<?php echo $this->get_field_name('description'); ?>"><?php echo $description; ?></textarea>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('style'); ?>"><?php _e('Select Style:'); ?></label>
            <select id="<?php echo $this->get_field_id('style'); ?>" name="<?php echo $this->get_field_name('style'); ?>">
                <option value="none"<?php selected( $style, 'none' ); ?>>None</option>';
                <option value="circle"<?php selected( $style, 'circle' ); ?>>Circle</option>';
            </select>
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('url'); ?>"><?php _e('URL:') ?></label>
            <input type="text" class="widefat" id="<?php echo $this->get_field_id('url'); ?>" name="<?php echo $this->get_field_name('url'); ?>" value="<?php echo $url; ?>" />
        </p>
        <?php
    }
}

/**
 * Module Name: Image Widget
 * Module Description: Easily add images to your theme's sidebar.
 * Sort Order: 20
 * First Introduced: 1.2
 */
class Bootstrap_Image_Widget extends WP_Widget {

	function Bootstrap_Image_Widget() {
		$widget_ops = array( 'classname' => 'widget_image', 'description' => __( "Display an image in your sidebar", 'webplantmedia' ) );
		$control_ops = array( 'width' => 400 );
		$this->WP_Widget( 'image', __( 'Image', 'webplantmedia' ), $widget_ops, $control_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );

		echo $before_widget;

		$title = apply_filters( 'widget_title', $instance['title'] );

		if ( $title )
			echo $before_title . esc_html( $title ) . $after_title;

		if ( '' != $instance['img_url'] ) {

			$output = '<img src="' . esc_attr( $instance['img_url'] ) .'" ';
			if ( '' != $instance['alt_text'] )
				$output .= 'alt="' . esc_attr( $instance['alt_text'] ) .'" ';
			if ( '' != $instance['img_title'] )
				$output .= 'title="' . esc_attr( $instance['img_title'] ) .'" ';
			//if ( '' != $instance['img_width'] )
				//$output .= 'width="' . esc_attr( $instance['img_width'] ) .'" ';
			//if ( '' != $instance['img_height'] )
				//$output .= 'height="' . esc_attr( $instance['img_height'] ) .'" ';
			$output .= '/>';
			if ( '' != $instance['link'] )
        $output = '<a class="thumbnail-link image-hover" href="' . esc_attr( $instance['link'] ) . '">' . $output . '</a>';
			if ( '' != $instance['caption'] )
				$output = $output . '<p class="sidebar-caption">' . esc_html( $instance['caption'] ) . '</p>';

			echo '<div class="webplantmedia-image-container">' . do_shortcode( $output ) . '</div>';
		}

		echo "\n" . $after_widget;
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		$instance['title']      = strip_tags( $new_instance['title'] );
		$instance['img_url']    = esc_url( $new_instance['img_url'], null, 'display' );
		$instance['alt_text']   = strip_tags( $new_instance['alt_text'] );
		$instance['img_title']  = strip_tags( $new_instance['img_title'] );
		$instance['caption']    = strip_tags( $new_instance['caption'] );
		//$instance['img_width']  = absint( $new_instance['img_width'] );
		//$instance['img_height'] = absint( $new_instance['img_height'] );
		$instance['link']       = esc_url( $new_instance['link'], null, 'display' );

		return $instance;
	}

	function form( $instance ) {
    wp_enqueue_media();
 
		// Defaults
		$instance = wp_parse_args( (array) $instance, array( 'title' => '', 'img_url' => '', 'alt_text' => '', 'img_title' => '', 'caption' => '', 'img_width' => '', 'img_height' => '', 'link' => '' ) );

		$title      = esc_attr( $instance['title'] );
		$img_url    = esc_url( $instance['img_url'], null, 'display' );
		$alt_text   = esc_attr( $instance['alt_text'] );
		$img_title  = esc_attr( $instance['img_title'] );
		$caption    = esc_attr( $instance['caption'] );
		//$img_width  = esc_attr( $instance['img_width'] );
		//$img_height = esc_attr( $instance['img_height'] );

		/*if ( !empty( $instance['img_url'] ) ) {
			// Download the url to a local temp file and then process it with getimagesize so we can filter out domains which are blocking us
			$tmp_file = download_url( $instance['img_url'], 30 );
			if ( ! is_wp_error( $tmp_file ) ) {
				$size = getimagesize( $tmp_file );

				if ( '' == $instance['img_width'] ) {
					$width = $size[0];
					$img_width = $width;
				} else {
					$img_width = absint( $instance['img_width'] );
				}

				if ( '' == $instance['img_height'] ) {
					$height = $size[1];
					$img_height = $height;
				} else {
					$img_height = absint( $instance['img_height'] );
				}

				unlink( $tmp_file );
			}
		}*/

		$link = esc_url( $instance['link'], null, 'display' );

		echo '<p><label for="' . $this->get_field_id( 'title' ) . '">' . esc_html__( 'Widget title:', 'webplantmedia' ) . '
			<input class="widefat" id="' . $this->get_field_id( 'title' ) . '" name="' . $this->get_field_name( 'title' ) . '" type="text" value="' . $title . '" />
			</label></p>
			<p><label for="' . $this->get_field_id( 'img_url' ) . '">' . esc_html__( 'Image URL:', 'webplantmedia' ) . '
			<input class="widefat" id="' . $this->get_field_id( 'img_url' ) . '" name="' . $this->get_field_name( 'img_url' ) . '" type="text" value="' . $img_url . '" />
      </label>
            <a href="#" class="button inline-button" onclick="webpmUploadImage.call(this, event)" data-target="#'.$this->get_field_id( 'img_url' ).'" title="Add Media"><span class="wp-media-buttons-icon"></span> Add Media</a>
            </p>
			<p><label for="' . $this->get_field_id( 'alt_text' ) . '">' . esc_html__( 'Alternate text:', 'webplantmedia' ) . '  <a href="http://support.wordpress.com/widgets/image-widget/#image-widget-alt-text" target="_blank">( ? )</a>
			<input class="widefat" id="' . $this->get_field_id( 'alt_text' ) . '" name="' . $this->get_field_name( 'alt_text' ) . '" type="text" value="' . $alt_text . '" />
			</label></p>
			<p><label for="' . $this->get_field_id( 'img_title' ) . '">' .  esc_html__( 'Image title:', 'webplantmedia' ) . ' <a href="http://support.wordpress.com/widgets/image-widget/#image-widget-title" target="_blank">( ? )</a>
			<input class="widefat" id="' . $this->get_field_id( 'img_title' ) . '" name="' . $this->get_field_name( 'img_title' ) . '" type="text" value="' . $img_title . '" />
			</label></p>
			<p><label for="' . $this->get_field_id( 'caption' ) . '">' . esc_html__( 'Caption:', 'webplantmedia' ) . ' <a href="http://support.wordpress.com/widgets/image-widget/#image-widget-caption" target="_blank">( ? )</a>
			<input class="widefat" id="' . $this->get_field_id( 'caption' ) . '" name="' . $this->get_field_name( 'caption' ) . '" type="text" value="' . $caption . '" />
			</label></p>';

		/*echo '<p><label for="' .  $this->get_field_id( 'img_width' ) . '">' . esc_html__( 'Width:', 'webplantmedia' ) . '
		<input size="3" id="' .  $this->get_field_id( 'img_width' ) . '" name="' . $this->get_field_name( 'img_width' ) . '" type="text" value="' .  $img_width . '" />
		</label>
		<label for="' . $this->get_field_id( 'img_height' ) . '">' . esc_html__( 'Height:', 'webplantmedia' ) . '
		<input size="3" id="' . $this->get_field_id( 'img_height' ) . '" name="' . $this->get_field_name( 'img_height' ) . '" type="text" value="' . $img_height . '" />
		</label><br />';*/
		//echo '<small>' . esc_html__( "If empty, we will attempt to determine the image size.", 'webplantmedia' ) . '</small></p>';

		echo '<p><label for="' . $this->get_field_id( 'link' ) . '">' . esc_html__( 'Link URL (when the image is clicked):', 'webplantmedia' ) . '
		<input class="widefat" id="' . $this->get_field_id( 'link' ) . '" name="' . $this->get_field_name( 'link' ) . '" type="text" value="' . $link . '" />
		</label></p>';
	}

} //Class Bootstrap_Image_Widget

?>
