<?php
/******************************************************************
Author: Chris Baldelomar
URL: http://webplantmedia.com

This page walks you through creating 
a custom post type and taxonomies. You
can edit this one or copy the following code 
to create another one. 

I put this in a separate file so as to 
keep it organized. I find it easier to edit
and change things if they are concentrated
in their own file.
******************************************************************/

/**
 * Register custom post type for theme
 */
add_action( 'init', 'webpm_custom_post');

/**
 * Include and setup custom metaboxes and fields.
 *
 * @package  Metaboxes
 * @license  http://www.opensource.org/licenses/gpl-license.php GPL v2.0 (or later)
 * @link     https://github.com/jaredatch/Custom-Metaboxes-and-Fields-for-WordPress
 */
add_filter( 'cmb_meta_boxes', 'cmb_webpm_metaboxes' );

/**
 * Validate filter  
 */
//add_filter( 'cmb_validate_text_medium', 'cmb_check_user_input', 10, 3 );
	
/**
 * webpm_custom_post 
 *
 * let's create the function for the custom type
 *
 * @access public
 * @return void
 */
function webpm_custom_post() {
	// creating (registering) the custom type 
	register_post_type( 'carousel_frame', /* (http://codex.wordpress.org/Function_Reference/register_post_type) */
	 	// let's now add all the options for this post type
		array(
			'labels' => array(
				'name' => __('Carousel', 'bonestheme'), /* This is the Title of the Group */
				'singular_name' => __('Frame', 'bonestheme'), /* This is the individual type */
				'all_items' => __('All Frames', 'bonestheme'), /* the all items menu item */
				'add_new' => __('Add New Frame', 'bonestheme'), /* The add new menu item */
				'add_new_item' => __('Add New Frame', 'bonestheme'), /* Add New Display Title */
				'edit' => __( 'Edit', 'bonestheme' ), /* Edit Dialog */
				'edit_item' => __('Edit Frame', 'bonestheme'), /* Edit Display Title */
				'new_item' => __('New Frame', 'bonestheme'), /* New Display Title */
				'view_item' => __('View Frame', 'bonestheme'), /* View Display Title */
				'search_items' => __('Search Frame', 'bonestheme'), /* Search Custom Type Title */ 
				'not_found' =>  __('Nothing found in the Database.', 'bonestheme'), /* This displays if there are no entries yet */ 
				'not_found_in_trash' => __('Nothing found in Trash', 'bonestheme'), /* This displays if there is nothing in the trash */
				'parent_item_colon' => ''
			), /* end of arrays */
			'description' => __( 'Frames for Carousel', 'bonestheme' ), /* Custom Type Description */
			'public' => false,
			'publicly_queryable' => true,
			'exclude_from_search' => true,
			'show_ui' => true,
			'query_var' => false,
			'menu_position' => 5, /* this is what order you want it to appear in on the left hand side menu */ 
			'menu_icon' => get_stylesheet_directory_uri() . '/img/custom-post-icon.png', /* the icon for the custom post type menu */
			'rewrite'	=> array( 'slug' => 'frame', 'with_front' => false ), /* you can specify its url slug */
			'has_archive' => false, /* you can rename the slug here */
			'capability_type' => 'page',
			'hierarchical' => true,
			/* the next one is important, it tells what's enabled in the post editor */
			'supports' => array( 'title', 'editor', 'thumbnail', 'revisions', 'page-attributes')
	 	)
	);

	// support examples
	//'supports' => array( 'title', 'editor', 'author', 'thumbnail', 'excerpt', 'trackbacks', 'custom-fields', 'comments', 'revisions', 'sticky')
	
    // this adds your post categories to your custom post type 
	//register_taxonomy_for_object_type('portfolio_type', 'portfolio');

    // this adds your post tags to your custom post type 
	//register_taxonomy_for_object_type('post_tag', 'custom_type');
} 

/**
 * Now let's add custom tags (these act like categories)
 * for more information on taxonomies, go here:
 * http://codex.wordpress.org/Function_Reference/register_taxonomy
 */
/*register_taxonomy( 'custom_tag', 
    array('custom_type'), [> if you change the name of register_post_type( 'custom_type', then you have to change this <]
    array('hierarchical' => false,    [> if this is false, it acts like tags <]                
        'labels' => array(
            'name' => __( 'Custom Tags', 'bonestheme' ), [> name of the custom taxonomy <]
            'singular_name' => __( 'Custom Tag', 'bonestheme' ), [> single taxonomy name <]
            'search_items' =>  __( 'Search Custom Tags', 'bonestheme' ), [> search title for taxomony <]
            'all_items' => __( 'All Custom Tags', 'bonestheme' ), [> all title for taxonomies <]
            'parent_item' => __( 'Parent Custom Tag', 'bonestheme' ), [> parent title for taxonomy <]
            'parent_item_colon' => __( 'Parent Custom Tag:', 'bonestheme' ), [> parent taxonomy title <]
            'edit_item' => __( 'Edit Custom Tag', 'bonestheme' ), [> edit custom taxonomy title <]
            'update_item' => __( 'Update Custom Tag', 'bonestheme' ), [> update title for taxonomy <]
            'add_new_item' => __( 'Add New Custom Tag', 'bonestheme' ), [> add new title for taxonomy <]
            'new_item_name' => __( 'New Custom Tag Name', 'bonestheme' ) [> name title for taxonomy <]
        ),
        'show_ui' => true,
        'query_var' => true,
    )
);*/
    
/**
 * cmb_webpm_metaboxes 
 *
 * Define the metabox and field configurations.
 * 
 * @param array $meta_boxes 
 * @access public
 * @return void
 */
function cmb_webpm_metaboxes( array $meta_boxes ) {

    // Start with an underscore to hide fields from custom fields list
    $prefix = '_webpm_';

    $meta_boxes[] = array(
        'id'         => 'heading_metabox',
        'title'      => 'Heading',
        'pages'      => array( 'page' ), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        'fields'     => array(
            array(
                'name' => 'H1',
                'desc' => 'Enter a custom heading title for you page different than your page title.',
                'id'   => $prefix . 'h1',
                'type' => 'text',
            ),
        ),
    );

    // Add other metaboxes as needed

    return $meta_boxes;
}

?>
