/**
 * Plugin:          Carousel 3D jQuery Plugin
 * Plugin URI:      http://webplantmedia.com/
 * Description:     jQuery plugin that turns any element into a 3D carousel
 * Version:         1.0.0
 * Author:          Chris Baldelomar
 * Author URI:      http://webplantmedia.com
 * License:         GNU General Public License version 3.0
 * License URI:     http://www.gnu.org/licenses/gpl-3.0.html
 */
(function( $ ){
    $.fn.bootstrapModalGallery = function( options ) {  
    // default options
    var defaults = {  
        selector: '.modal-popup',
        baseurl: '',
        pinit: true,
        singleImage: false 
    };  

    // merge default options with user defined options
    var options = $.extend(defaults, options);  

    this.each(function(){
        // cache element
        var $gallery;
        var $links;
        if (options.singleImage) {
            $links = $(this).parent('a');
        }
        else {
            $gallery = $(this);
            $links = $gallery.find(options.selector);
        }
        var $target;
        var $backdrop;
        var $current;
        var $modal;
        var $next;
        var $prev;
        var linksLength = parseInt( $links.length, 10 );

        // functions for plugin
        var methods = {
            // begins plugin process
            init : function () {
                if ($links.length > 0) {
                    $target = $('#webpm-popup-modals');
                    if ($target.length == 0) {
                        $('body').append('<div id="webpm-popup-modals" class="container"></div>');
                        $target = $('#webpm-popup-modals');
                    }
                    $links.click( methods.popup );
                }

            },
            popup : function( event ) {
                $current = $(this);
                var href = $current.attr('href');
                var ext = href.toLowerCase().split('.').pop();
                if (typeof ext == 'string') {
                    switch(ext) {
                    case 'jpg':
                    case 'jpeg':
                    case 'png':
                    case 'gif':
                        event.preventDefault ? event.preventDefault() : event.returnValue = false;
                        methods.process.apply(this);
                        break;
                    }
                }
            },
            process : function ( event ) {
                var html = methods.modal.apply(this);
                $target.html(html);
                $modal = $target.find('#modal-popup');

                $modal.modal('show');
                if (linksLength > 1) {
                    $modal.find('.modal-body').click(methods.next).addClass('hand-over');
                    $modal.find('#right-modal-control').click(methods.next);
                    $modal.find('#left-modal-control').click(methods.prev);
                }
                else {
                    $modal.find('.modal-body').removeClass('hand-over');
                }

                var image = new Image(); 
                image.onload = methods.imageLoaded;
                image.src = $current.attr('href');

                methods.updateNavigation();
            },
            next : function ( ) {
                $modal.find('.modal-loading').show();

                var image = new Image(); 
                image.onload = methods.imageLoaded;
                $current = $next;
                image.src = $current.attr('href');

                methods.updateNavigation();
            },
            prev : function ( ) {
                $modal.find('.modal-loading').show();

                var image = new Image(); 
                image.onload = methods.imageLoaded;
                $current = $prev;
                image.src = $current.attr('href');

                methods.updateNavigation();
            },
            updateNavigation : function () {
                var current = $current[0];
                var idx = $links.index(current);
                var next = $links[idx + 1] || $links[0];
                var prev = $links[idx - 1] || $links[linksLength-1];

                $next = $(next);
                $prev = $(prev);
            },
            viewport : function ( ) {
                var e = window
                , a = 'inner';
                if ( !( 'innerWidth' in window ) ) {
                    a = 'client';
                    e = document.documentElement || document.body;
                }
                return { width : e[ a+'Width' ] , height : e[ a+'Height' ] }
            },
            imageLoaded : function ( ) {
                $modal.find('.modal-loading').hide();

                var w, h, width, height;

                var viewport = methods.viewport.apply();
                var modalPadding = parseInt($modal.children('.modal-body').css('padding-top'), 10);
                var browserHeight = viewport.height;
                var browserWidth = viewport.width;
                var modalOffset = parseInt( 0.1 * browserHeight );
                loadedWidth = this.width;  
                loadedHeight = this.height;  
                browserHeight = browserHeight - modalPadding - modalPadding - modalOffset - modalOffset;
                browserWidth = browserWidth - modalPadding - modalPadding - modalOffset - modalOffset;

                if (loadedHeight > browserHeight) {
                    h = browserHeight;
                    w = h * loadedWidth / loadedHeight;
                    if (w > browserWidth) {
                        w = browserWidth;
                        h = w * loadedHeight / loadedWidth;
                    }
                }
                else if (loadedWidth > browserWidth) {
                    w = browserWidth;
                    h = w * loadedHeight / loadedWidth;
                }
                else {
                    w = loadedWidth;
                    h = loadedHeight;
                }
                h = Math.ceil(h);
                w = Math.ceil(w);

                var marginLeft = Math.ceil(w/2) + modalPadding;
                var modalWidth = w + modalPadding + modalPadding;
                    
                var title = $current.attr('title');
                var caption = $current.next('.wp-caption-text').html();

                $modal
                    .width(modalWidth)
                    .css('margin-left', '-'+marginLeft+'px')
                    .find('.modal-body .modal-window')
                        .html('<img src="'+this.src+'" width="'+w+'" height="'+h+'" />');

                $modal.find('.caption-text').html(caption);

                if (options.pinit) {
                    $modal.find('#modal-pinit').attr('href', 'http://pinterest.com/pin/create/button/?url='+encodeURIComponent(window.location.href)+'&media='+encodeURIComponent(this.src));
                }
            },
            modal : function( ) {
                var html;

                html  = '<div id="modal-popup" class="modal hide fade">';
                html += '   <div class="modal-body">';
                html += '       <div class="modal-window">';
                html += '       </div>';
                if (options.pinit) {
                html += '       <a id="modal-pinit" target="_blank" href="" data-pin-do="buttonPin" data-pin-config="none">';
                html += '           <img src="//assets.pinterest.com/images/pidgets/pin_it_button.png" />';
                html += '       </a>';
                }
                html += '   </div>';
                html += '   <div class="modal-caption">';
                html += '       <div class="caption-text">';
                html += '       </div>';
                html += '   </div>';
                html += '   <div class="modal-loading">';
                html += '   </div>';
                if (linksLength > 1) {
                html += '   <a id="left-modal-control" class="left modal-control"><img src="'+options.baseurl+'/img/template/left-arrow.png" /></a>';
                html += '   <a id="right-modal-control" class="right modal-control"><img src="'+options.baseurl+'/img/template/right-arrow.png" /></a>';
                }
                html += '</div>';

                return html;
            }
        };

        // initialize plugin
        return methods.init.apply( this );
    });
    return this;
  };
})( jQuery );
