<?php

/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */

function optionsframework_option_name() {
    $option_id = 'of_'.THEME_NAME;
    $option_id = preg_replace("/\W/", "_", strtolower($option_id) );

    $optionsframework_settings = get_option( 'optionsframework' );
    $optionsframework_settings['id'] = $option_id;
    update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * optionsframework_options 
 *
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'options_framework_theme'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 * 
 * @access public
 * @return void
 */
function optionsframework_options() {

    $typography_mixed_fonts = get_options_typography_mixed_fonts();
        
    // If using image radio buttons, define a directory path
    $imagepath =  get_template_directory_uri() . '/img/';

    $options = array();

    /* BANNER */
    $options[] = array(
        'name' => __('Banner', 'options_framework_theme'),
        'type' => 'heading');

    $options[] = array(
        'name' => __('Logo Image', 'options_framework_theme'),
        'desc' => __('Upload your logo image.', 'options_framework_theme'),
        'id' => 'logo_image',
        'std' => THEME_URI . '/img/template/logo.jpg',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Logo Top Offset', 'options_framework_theme'),
        'desc' => __('Set the spacing between the top of the logo and the header.', 'options_framework_theme'),
        'id' => 'logo_top_offset',
        'std' => '0',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            '0' => '0px',
            '2' => '2px',
            '4' => '4px',
            '6' => '6px',
            '8' => '8px',
            '10' => '10px',
            '12' => '12px',
            '14' => '14px',
            '16' => '16px',
            '18' => '18px',
            '20' => '20px',
            '22' => '22px',
            '24' => '24px',
            '26' => '26px',
            '28' => '28px',
            '30' => '30px',
            '32' => '32px',
            '34' => '34px',
            '36' => '36px',
            '38' => '38px',
            '40' => '40px',
            '42' => '42px',
            '44' => '44px',
            '46' => '46px',
            '48' => '48px',
            '50' => '50px',
            '52' => '52px',
            '54' => '54px',
            '56' => '56px',
            '58' => '58px',
            '60' => '60px',
            '62' => '62px',
            '64' => '64px',
            '66' => '66px',
            '68' => '68px',
            '70' => '70px',
            '72' => '72px',
            '74' => '74px',
            '76' => '76px',
            '78' => '78px',
            '80' => '80px',
            '82' => '82px',
            '84' => '84px',
            '86' => '86px',
            '88' => '88px',
            '90' => '90px',
            '92' => '92px',
            '94' => '94px',
            '96' => '96px',
            '98' => '98px',
            '100' => '100px',
            '102' => '102px',
            '104' => '104px',
            '106' => '106px',
            '108' => '108px',
            '110' => '110px',
            '112' => '112px',
            '114' => '114px',
            '116' => '116px',
            '118' => '118px',
            '120' => '120px',
            '122' => '122px',
            '124' => '124px',
            '126' => '126px',
            '128' => '128px',
            '130' => '130px',
            '132' => '132px',
            '134' => '134px',
            '136' => '136px',
            '138' => '138px',
            '140' => '140px',
        ));
 
    $options[] = array(
        'name' => __('Logo Bottom Offset', 'options_framework_theme'),
        'desc' => __('Set the spacing between the bottom of the logo and the header.', 'options_framework_theme'),
        'id' => 'logo_bottom_offset',
        'std' => '0',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            '0' => '0px',
            '2' => '2px',
            '4' => '4px',
            '6' => '6px',
            '8' => '8px',
            '10' => '10px',
            '12' => '12px',
            '14' => '14px',
            '16' => '16px',
            '18' => '18px',
            '20' => '20px',
            '22' => '22px',
            '24' => '24px',
            '26' => '26px',
            '28' => '28px',
            '30' => '30px',
            '32' => '32px',
            '34' => '34px',
            '36' => '36px',
            '38' => '38px',
            '40' => '40px',
            '42' => '42px',
            '44' => '44px',
            '46' => '46px',
            '48' => '48px',
            '50' => '50px',
            '52' => '52px',
            '54' => '54px',
            '56' => '56px',
            '58' => '58px',
            '60' => '60px',
            '62' => '62px',
            '64' => '64px',
            '66' => '66px',
            '68' => '68px',
            '70' => '70px',
            '72' => '72px',
            '74' => '74px',
            '76' => '76px',
            '78' => '78px',
            '80' => '80px',
            '82' => '82px',
            '84' => '84px',
            '86' => '86px',
            '88' => '88px',
            '90' => '90px',
            '92' => '92px',
            '94' => '94px',
            '96' => '96px',
            '98' => '98px',
            '100' => '100px',
            '102' => '102px',
            '104' => '104px',
            '106' => '106px',
            '108' => '108px',
            '110' => '110px',
            '112' => '112px',
            '114' => '114px',
            '116' => '116px',
            '118' => '118px',
            '120' => '120px',
            '122' => '122px',
            '124' => '124px',
            '126' => '126px',
            '128' => '128px',
            '130' => '130px',
            '132' => '132px',
            '134' => '134px',
            '136' => '136px',
            '138' => '138px',
            '140' => '140px',
        ));

    $options[] = array(
        'name' => __('Logo Side Padding', 'options_framework_theme'),
        'desc' => __('Set the side padding between your logo and the edge of your page.', 'options_framework_theme'),
        'id' => 'logo_side_padding',
        'std' => '0',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            '0' => '0px',
            '2' => '2px',
            '4' => '4px',
            '6' => '6px',
            '8' => '8px',
            '10' => '10px',
            '12' => '12px',
            '14' => '14px',
            '16' => '16px',
            '18' => '18px',
            '20' => '20px',
            '22' => '22px',
            '24' => '24px',
            '26' => '26px',
            '28' => '28px',
            '30' => '30px',
            '32' => '32px',
            '34' => '34px',
            '36' => '36px',
            '38' => '38px',
            '40' => '40px',
            '42' => '42px',
            '44' => '44px',
            '46' => '46px',
            '48' => '48px',
            '50' => '50px',
            '52' => '52px',
            '54' => '54px',
            '56' => '56px',
            '58' => '58px',
            '60' => '60px',
            '62' => '62px',
            '64' => '64px',
            '66' => '66px',
            '68' => '68px',
            '70' => '70px',
            '72' => '72px',
            '74' => '74px',
            '76' => '76px',
            '78' => '78px',
            '80' => '80px',
            '82' => '82px',
            '84' => '84px',
            '86' => '86px',
            '88' => '88px',
            '90' => '90px',
            '92' => '92px',
            '94' => '94px',
            '96' => '96px',
            '98' => '98px',
            '100' => '100px',
            '102' => '102px',
            '104' => '104px',
            '106' => '106px',
            '108' => '108px',
            '110' => '110px',
            '112' => '112px',
            '114' => '114px',
            '116' => '116px',
            '118' => '118px',
            '120' => '120px',
            '122' => '122px',
            '124' => '124px',
            '126' => '126px',
            '128' => '128px',
            '130' => '130px',
            '132' => '132px',
            '134' => '134px',
            '136' => '136px',
            '138' => '138px',
            '140' => '140px',
        ));

    $options[] = array(
        'name' => __('Logo Align', 'options_framework_theme'),
        'desc' => __('Choose whether you want your logo to be aligned to the left, to the right, or centered', 'options_framework_theme'),
        'id' => 'logo_align',
        'std' => 'right',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            'left' => 'Left',
            'center' => 'Center',
            'right' => 'Right'
        ));

    $options[] = array(
        'name' => __('Banner Background', 'options_framework_theme'),
        'desc' => __('Upload a background image for the banner of your website.', 'options_framework_theme'),
        'id' => 'banner_background',
        'std' => array(
            'color' => '',
            'image' => '',
            'repeat' => 'no-repeat',
            'position' => 'top center',
            'attachment'=> 'scroll'),
        'type' => 'background');

    /* MENU */
    $options[] = array(
        'name' => __('Menu', 'options_framework_theme'),
        'type' => 'heading');

    $options[] = array(
        'name' => __('Menu Align', 'options_framework_theme'),
        'desc' => __('Choose whether you want your menu to be aligned to the left, to the right, or centered', 'options_framework_theme'),
        'id' => 'menu_align',
        'std' => 'right',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            'left' => 'Left',
            'center' => 'Center',
            'right' => 'Right'
        ));

    $options[] = array( 'name' => 'Menu/Navigation Font',
        'desc' => 'Choose a font for your menu pages.',
        'id' => 'menu_font',
        'std' => 'Josefin+Slab',
        'type' => 'select',
        'class' => 'google-fonts',
        'options' => $typography_mixed_fonts);

    $options[] = array(
        'name' => __('Menu Font Size', 'options_framework_theme'),
        'desc' => __('Set the font size of your menu.', 'options_framework_theme'),
        'id' => 'menu_font_size',
        'std' => '21',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            '12' => '12px',
            '13' => '13px',
            '14' => '14px',
            '15' => '15px',
            '16' => '16px',
            '17' => '17px',
            '18' => '18px',
            '19' => '19px',
            '20' => '20px',
            '21' => '21px',
            '22' => '22px',
            '23' => '23px',
            '24' => '24px',
            '25' => '25px',
            '26' => '26px',
            '27' => '27px',
            '28' => '28px',
            '29' => '29px',
            '30' => '30px',
            '31' => '31px',
            '32' => '32px',
            '33' => '33px',
            '34' => '34px',
            '35' => '35px',
            '36' => '36px'
        ));

    $options[] = array(
        'name' => __('Menu Text Transform', 'options_framework_theme'),
        'desc' => __('Controls the capitalization of your menu text.', 'options_framework_theme'),
        'id' => 'menu_text_transform',
        'std' => 'none',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            'none' => 'No Transform',
            'uppercase' => 'Uppercase',
            'capitalize' => 'Capitalize',
            'lowercase' => 'Lowercase'
        ));

    $options[] = array(
        "name" => "Menubar Height",
        'desc' => 'Set Height of Menu Bar.',
        "id" => "menu_bar_height",
        "std" => '40',
        "class" => 'hidden',
        "type" => "text");

    $options[] = array(
        "name" => "Dropdown Height",
        'desc' => 'Set Height of dropdown links.',
        "id" => "dropdown_height",
        "std" => '40',
        "class" => 'hidden',
        "type" => "text");

    $options[] = array(
        'name' => __('Menu Text Padding Top', 'options_framework_theme'),
        'desc' => __('Some Google Fonts will not perfectly center vertically in a menu. Add a top padding value for complete control.', 'options_framework_theme'),
        'id' => 'menu_text_padding_top',
        'std' => '6',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            '0' => '0px',
            '1' => '1px',
            '2' => '2px',
            '3' => '3px',
            '4' => '4px',
            '5' => '5px',
            '6' => '6px',
            '7' => '7px',
            '8' => '8px',
            '9' => '9px',
            '10' => '10px',
        ));

    $options[] = array(
        'name' => __('Menu Text Padding Bottom.', 'options_framework_theme'),
        'desc' => __('Some Google Fonts will not perfectly center vertically in a menu. Add a bottom padding value for complete control.', 'options_framework_theme'),
        'id' => 'menu_text_padding_bottom',
        'std' => '0',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            '0' => '0px',
            '1' => '1px',
            '2' => '2px',
            '3' => '3px',
            '4' => '4px',
            '5' => '5px',
            '6' => '6px',
            '7' => '7px',
            '8' => '8px',
            '9' => '9px',
            '10' => '10px',
        ));

    $options[] = array(
        "name" => "Menu Background Color",
        'desc' => 'Choose the background color for your menubar.',
        "id" => "menu_background_color",
        "std" => '#F7EADF',
        "type" => "color");

    $options[] = array(
        "name" => "Menu Font Color",
        'desc' => 'Choose the color for your menu pages.',
        "id" => "menu_font_color",
        "std" => '#D0A597',
        "type" => "color");

    $options[] = array(
        "name" => "Menu Font Hover Color",
        'desc' => 'Choose the color to display when you hover your mouse over your menu pages.',
        "id" => "menu_font_hover_color",
        "std" => '#ffffff',
        "type" => "color");

    $options[] = array(
        "name" => "Menu Button Color",
        'desc' => 'Choose the background color for your menu button.',
        "id" => "menu_button_color",
        "std" => '#ffffff',
        "type" => "color");

    $options[] = array(
        "name" => "Menu Button Hover Color",
        'desc' => 'Choose the background color for your menu button when hovering.',
        "id" => "menu_button_hover_color",
        "std" => '#F0C69E',
        "type" => "color");

    $options[] = array(
        "name" => "Menu Button Accent Color",
        'desc' => 'Choose the accent color for your menubar.',
        "id" => "menu_button_accent_color",
        "std" => '#F7EADF',
        "type" => "color");

    $options[] = array(
        'name' => __('Show Home in Menu', 'options_framework_theme'),
        'desc' => __('Show the default Home Link in the Menu Bar.', 'options_framework_theme'),
        'id' => 'show_home',
        'std' => 1,
        'type' => 'checkbox');

    /* HEADER */
    $options[] = array(
        'name' => __('Heading', 'options_framework_theme'),
        'type' => 'heading');

    $options[] = array( 'name' => 'Header Font',
        'desc' => 'Change the font in your header.',
        'id' => 'header_font',
        'std' => 'Josefin+Slab',
        'type' => 'select',
        'class' => 'google-fonts',
        'options' => $typography_mixed_fonts);

    $options[] = array(
        'name' => __('Header Font Size', 'options_framework_theme'),
        'desc' => __('Set the font size of your header.', 'options_framework_theme'),
        'id' => 'header_font_size',
        'std' => '26',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            '12' => '12px',
            '13' => '13px',
            '14' => '14px',
            '15' => '15px',
            '16' => '16px',
            '17' => '17px',
            '18' => '18px',
            '19' => '19px',
            '20' => '20px',
            '21' => '21px',
            '22' => '22px',
            '23' => '23px',
            '24' => '24px',
            '25' => '25px',
            '26' => '26px',
            '27' => '27px',
            '28' => '28px',
            '29' => '29px',
            '30' => '30px',
            '31' => '31px',
            '32' => '32px',
            '33' => '33px',
            '34' => '34px',
            '35' => '35px',
            '36' => '36px'
        ));

    $options[] = array(
        'name' => __('Header Text Transform', 'options_framework_theme'),
        'desc' => __('Controls the capitalization of your header text.', 'options_framework_theme'),
        'id' => 'header_text_transform',
        'std' => 'none',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            'none' => 'No Transform',
            'uppercase' => 'Uppercase',
            'capitalize' => 'Capitalize',
            'lowercase' => 'Lowercase'
        ));

    $options[] = array(
        "name" => "Header Font Color",
        'desc' => 'Select the color of your header font.',
        "id" => 'header_font_color',
        "std" => '#F0C69E',
        "type" => "color");

    /* BODY */
    $options[] = array(
        'name' => __('Body', 'options_framework_theme'),
        'type' => 'heading');

    $options[] = array( 'name' => 'Text Font',
        'desc' => 'Change the typography of your paragraphs and quotes.',
        'id' => 'text_font',
        'std' => 'Arial',
        'type' => 'select',
        'class' => 'google-fonts',
        'options' => $typography_mixed_fonts);

    $options[] = array(
        'name' => __('Text Font Size', 'options_framework_theme'),
        'desc' => __('Set the font size of your text.', 'options_framework_theme'),
        'id' => 'text_font_size',
        'std' => '15',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            '12' => '12px',
            '13' => '13px',
            '14' => '14px',
            '15' => '15px',
            '16' => '16px',
            '17' => '17px',
            '18' => '18px',
            '19' => '19px',
            '20' => '20px',
            '21' => '21px',
            '22' => '22px',
            '23' => '23px',
            '24' => '24px',
            '25' => '25px',
            '26' => '26px',
            '27' => '27px',
            '28' => '28px',
            '29' => '29px',
            '30' => '30px',
            '31' => '31px',
            '32' => '32px',
            '33' => '33px',
            '34' => '34px',
            '35' => '35px',
            '36' => '36px'
        ));

    $options[] = array(
        "name" => "Text Font Color",
        'desc' => 'Select the color of your text.',
        "id" => 'text_font_color',
        "std" => '#94918F',
        "type" => "color");

    $options[] = array(
        "name" => "Link Font Color",
        'desc' => 'Select the color of linked text.',
        "id" => 'link_font_color',
        "std" => '#F0C69E',
        "type" => "color");

    $options[] = array(
        "name" => "Link Font Hover Color",
        'desc' => 'Select the color of linked text when the mouse hovers over it.',
        "id" => "link_font_hover_color",
        "std" => '#EBA3A9',
        "type" => "color");

    $options[] = array(
        'name' => __('Body Background', 'options_framework_theme'),
        'desc' => __('Upload a background image for the body of your website.', 'options_framework_theme'),
        'id' => 'body_background',
        'std' => array(
            'color' => '',
            'image' => 'none',
            'repeat' => 'repeat',
            'position' => 'top center',
            'attachment'=> 'scroll'),
        'type' => 'background');

    $options[] = array( 'name' => 'Date Font',
        'desc' => 'Set font style for the date on the blog page.',
        'id' => 'date_font',
        'std' => 'Josefin+Sans',
        'type' => 'select',
        'class' => 'google-fonts',
        'options' => $typography_mixed_fonts);

    $options[] = array(
        'name' => __('Date Font Size', 'options_framework_theme'),
        'desc' => __('Set the font size of your date string.', 'options_framework_theme'),
        'id' => 'date_font_size',
        'std' => '19',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            '12' => '12px',
            '13' => '13px',
            '14' => '14px',
            '15' => '15px',
            '16' => '16px',
            '17' => '17px',
            '18' => '18px',
            '19' => '19px',
            '20' => '20px',
            '21' => '21px',
            '22' => '22px',
            '23' => '23px',
            '24' => '24px',
            '25' => '25px',
            '26' => '26px',
            '27' => '27px',
            '28' => '28px',
            '29' => '29px',
            '30' => '30px',
            '31' => '31px',
            '32' => '32px',
            '33' => '33px',
            '34' => '34px',
            '35' => '35px',
            '36' => '36px'
        ));

    $options[] = array(
        "name" => "Date Font Color",
        'desc' => 'Set the font color of your date.',
        "id" => "date_font_color",
        "std" => '#EBA3A9',
        "type" => "color");

    $options[] = array(
        'name' => __('Date Text Transform', 'options_framework_theme'),
        'desc' => __('Controls the capitalization of your date text.', 'options_framework_theme'),
        'id' => 'date_text_transform',
        'std' => 'uppercase',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            'none' => 'No Transform',
            'uppercase' => 'Uppercase',
            'capitalize' => 'Capitalize',
            'lowercase' => 'Lowercase'
        ));

    $options[] = array(
        'name' => __('Byline Background', 'options_framework_theme'),
        'desc' => __('Set background for your byline.', 'options_framework_theme'),
        'id' => 'byline_background',
        'std' => array(
            'color' => '#f7eadf',
            'image' => '',
            'repeat' => 'no-repeat',
            'position' => 'top center',
            'attachment'=> 'scroll'),
        'type' => 'background');

    $options[] = array(
        'name' => __('Footer Font Size', 'options_framework_theme'),
        'desc' => __('Set the font size of your footer.', 'options_framework_theme'),
        'id' => 'footer_font_size',
        'std' => '14',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            '10' => '10px',
            '11' => '11px',
            '12' => '12px',
            '13' => '13px',
            '14' => '14px',
            '15' => '15px',
            '16' => '16px',
            '17' => '17px',
            '18' => '18px',
            '19' => '19px',
            '20' => '20px',
            '21' => '21px',
            '22' => '22px',
            '23' => '23px',
            '24' => '24px',
            '25' => '25px',
            '26' => '26px',
            '27' => '27px',
            '28' => '28px',
            '29' => '29px',
            '30' => '30px',
            '31' => '31px',
            '32' => '32px',
            '33' => '33px',
            '34' => '34px',
            '35' => '35px',
            '36' => '36px'
        ));

    $options[] = array(
        "name" => "Footer Font Color",
        'desc' => 'Set the font color inside your footer.',
        "id" => "footer_font_color",
        "std" => '#94918F',
        "type" => "color");

    $options[] = array(
        'name' => __('Image Caption Font Size', 'options_framework_theme'),
        'desc' => __('Set the font size of your image captions', 'options_framework_theme'),
        'id' => 'image_caption_font_size',
        'std' => '12',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            '8' => '8px',
            '9' => '9px',
            '10' => '10px',
            '11' => '11px',
            '12' => '12px',
            '13' => '13px',
            '14' => '14px',
            '15' => '15px',
            '16' => '16px',
            '17' => '17px',
            '18' => '18px',
            '19' => '19px',
            '20' => '20px',
            '21' => '21px',
            '22' => '22px',
            '23' => '23px',
            '24' => '24px',
            '25' => '25px',
            '26' => '26px',
            '27' => '27px',
            '28' => '28px',
            '29' => '29px',
            '30' => '30px',
            '31' => '31px',
            '32' => '32px',
            '33' => '33px',
            '34' => '34px',
            '35' => '35px',
            '36' => '36px'
        ));

    $options[] = array(
        "name" => "Carousel Caption Color",
        'desc' => 'Set the carousel caption color',
        "id" => "carousel_caption_color",
        "std" => '#7D634D',
        "type" => "color");

    /* BUTTONS */
    $options[] = array(
        'name' => __('Buttons', 'options_framework_theme'),
        'type' => 'heading');

    $options[] = array(
        "name" => "Button Background Color",
        'desc' => 'Set background color for your button',
        "id" => "button_background_color",
        "std" => '#F8F5F2',
        "type" => "color");

    $options[] = array(
        "name" => "Button Text Color",
        'desc' => 'Set text color for your button',
        "id" => "button_text_color",
        "std" => '#94918F',
        "type" => "color");

    $options[] = array(
        "name" => "Button Border Color",
        'desc' => 'Set border color for your button',
        "id" => "button_border_color",
        "std" => '#F8F5F2',
        "type" => "color");

    $options[] = array(
        "name" => "Button Background Hover Color",
        'desc' => 'Set background color for your button when hovering',
        "id" => "button_background_hover_color",
        "std" => '#F7EADF',
        "type" => "color");

    $options[] = array(
        "name" => "Button Text Hover Color",
        'desc' => 'Set text color for your button when hovering',
        "id" => "button_text_hover_color",
        "std" => '#94918F',
        "type" => "color");

    $options[] = array(
        "name" => "Button Border Hover Color",
        'desc' => 'Set border color for your button when hovering',
        "id" => "button_border_hover_color",
        "std" => '#FFFFFF',
        "type" => "color");

    /* SIDEBAR SETTINGS */
    $options[] = array(
        'name' => 'Sidebar',
        'type' => 'heading');

    $options[] = array(
        'name' => __('About Me Image', 'options_framework_theme'),
        'desc' => __('Upload your "About Me" image.', 'options_framework_theme'),
        'id' => 'about_me_image',
        'std' => THEME_URI . '/img/template/headshot.png',
        'type' => 'upload');

    $options[] = array( 'name' => 'Widget Header Font',
        'desc' => 'Set your widget heading font.',
        'id' => 'widget_header_font',
        'std' => 'Josefin+Sans',
        'type' => 'select',
        'class' => 'google-fonts',
        'options' => $typography_mixed_fonts);

    $options[] = array(
        'name' => __('Widget Font Size', 'options_framework_theme'),
        'desc' => __('Set the font size of your widget.', 'options_framework_theme'),
        'id' => 'widget_font_size',
        'std' => '17',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            '12' => '12px',
            '13' => '13px',
            '14' => '14px',
            '15' => '15px',
            '16' => '16px',
            '17' => '17px',
            '18' => '18px',
            '19' => '19px',
            '20' => '20px',
            '21' => '21px',
            '22' => '22px',
            '23' => '23px',
            '24' => '24px',
            '25' => '25px',
            '26' => '26px',
            '27' => '27px',
            '28' => '28px',
            '29' => '29px',
            '30' => '30px',
            '31' => '31px',
            '32' => '32px',
            '33' => '33px',
            '34' => '34px',
            '35' => '35px',
            '36' => '36px'
        ));

    $options[] = array(
        "name" => "Widget Font Color",
        'desc' => 'Set the font color of your widget title.',
        "id" => "widget_font_color",
        "std" => '#EBA3A9',
        "type" => "color");

    $options[] = array(
        'name' => __('Widget Text Transform', 'options_framework_theme'),
        'desc' => __('Controls the capitalization of your widget text.', 'options_framework_theme'),
        'id' => 'widget_text_transform',
        'std' => 'uppercase',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            'none' => 'No Transform',
            'uppercase' => 'Uppercase',
            'capitalize' => 'Capitalize',
            'lowercase' => 'Lowercase'
        ));

    $options[] = array(
        'name' => __('Widget Background', 'options_framework_theme'),
        'desc' => __('Set background for widget header.', 'options_framework_theme'),
        'id' => 'widget_background',
        'std' => array(
            'color' => '#f7eadf',
            'image' => '',
            'repeat' => 'no-repeat',
            'position' => 'top center',
            'attachment'=> 'scroll'),
        'type' => 'background');

    $options[] = array(
        'name' => __('Sidebar Text Align', 'options_framework_theme'),
        'desc' => __('Do you want the content inside the sidebar to be left, centered, or right aligned?', 'options_framework_theme'),
        'id' => 'sidebar_align',
        'std' => 'right',
        'type' => 'select',
        'class' => 'mini',
        'options' => array(
            'left' => 'Left',
            'center' => 'Center',
            'right' => 'Right'
        ));

    $options[] = array(
        'name' => 'Sidebar Position',
        'desc' => 'Choose the position of your sidebar',
        'id' => 'sidebar',
        'std' => 'right',
        'type' => 'images',
        'options' => array(
            'left' => $imagepath . 'left-sidebar.png',
            'right' => $imagepath . 'right-sidebar.png')
    );

    $options[] = array(
        'name' => __('Show Sidebar on Blog', 'options_framework_theme'),
        'desc' => __('Show the sidebar on your blog', 'options_framework_theme'),
        'id' => 'show_sidebar_on_blog',
        'std' => 1,
        'type' => 'checkbox');

    /*$options[] = array(
        "name" => "Sidebar Background Color",
        'desc' => 'Select the background color of your sidebar.',
        "id" => 'sidebar_background_color',
        "std" => '#dd8765',
        "type" => "color");*/

    /* MISC */
    $options[] = array(
        'name' => __('Misc', 'options_framework_theme'),
        'type' => 'heading');

    $options[] = array(
        'name' => __('Responsive Website', 'options_framework_theme'),
        'desc' => __('Check whether you want your site to be responsive for mobile and tablet devices', 'options_framework_theme'),
        'id' => 'responsive_website',
        'std' => 1,
        'type' => 'checkbox');

    $options[] = array(
        'name' => __('Blog Format- Display Post Excerpt', 'options_framework_theme'),
        'desc' => __('Check this box if you want your blog page to display an excerpt of your post (with link to full post content), rather than your full post content.', 'options_framework_theme'),
        'id' => 'show_excerpt',
        'std' => 0,
        'type' => 'checkbox');

    $options[] = array(
        'name' => __('Favicon', 'options_framework_theme'),
        'desc' => __('Upload your favicon. Favicons must be a .ico file. Dimensions should measure 16x16 pixels. Go to <a href="http://www.faviconer.com/">faviconer.com</a> if you need help generating an .ico file.', 'options_framework_theme'),
        'id' => 'favicon',
        'std' => THEME_URI . '/img/template/favicon.ico',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Post Signature', 'options_framework_theme'),
        'desc' => __('Upload you post signature image. Can be a .jpg, .png, etc', 'options_framework_theme'),
        'id' => 'post_signature',
        'std' => THEME_URI . '/img/template/signature.jpg',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Code in Header', 'options_framework_theme'),
        'desc' => __('Insert javascript or any meta information in your head section of your HTML document', 'options_framework_theme'),
        'id' => 'javascript_header',
        'std' => '',
        'type' => 'code');
    
    $options[] = array(
        'name' => __('Code at Beginning of Body Content', 'options_framework_theme'),
        'desc' => __('Insert javascript or HTML in the beginning of your body content', 'options_framework_theme'),
        'id' => 'body_content_code',
        'std' => '',
        'type' => 'code');
    
    $options[] = array(
        'name' => __('Code in Footer', 'options_framework_theme'),
        'desc' => __('Insert javascript or HTML in your footer of your HTML document', 'options_framework_theme'),
        'id' => 'javascript_footer',
        'std' => '',
        'type' => 'code');
    
    /* Social Media */
    $options[] = array(
        'name' => __('Social Media', 'options_framework_theme'),
        'type' => 'heading');

    $options[] = array(
        'name' => __('Social Icons in Header', 'options_framework_theme'),
        'desc' => __('Show your social media icons in your header', 'options_framework_theme'),
        'id' => 'social_header_icons',
        'std' => 0,
        'type' => 'checkbox');

    $options[] = array(
        'name' => __('Pinterest Icon', 'options_framework_theme'),
        'desc' => __('Upload your Pinterest Icon', 'options_framework_theme'),
        'id' => 'pinterest_icon',
        'std' => THEME_URI . '/img/social-icons/pinterest.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Pinterest Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Pinterest. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'pinterest_url',
        'std' => 'http://angiemakes.com',
        'type' => 'text');

    $options[] = array(
        'name' => __('Twitter Icon', 'options_framework_theme'),
        'desc' => __('Upload your Twitter Icon', 'options_framework_theme'),
        'id' => 'twitter_icon',
        'std' => THEME_URI . '/img/social-icons/twitter.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Twitter Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Twitter. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'twitter_url',
        'std' => 'http://angiemakes.com',
        'type' => 'text');

    $options[] = array(
        'name' => __('Rss Icon', 'options_framework_theme'),
        'desc' => __('Upload your Rss Icon', 'options_framework_theme'),
        'id' => 'rss_icon',
        'std' => THEME_URI . '/img/social-icons/rss.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Rss Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Rss. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'rss_url',
        'std' => 'http://angiemakes.com',
        'type' => 'text');

    $options[] = array(
        'name' => __('Email Icon', 'options_framework_theme'),
        'desc' => __('Upload your Email Icon', 'options_framework_theme'),
        'id' => 'email_icon',
        'std' => THEME_URI . '/img/social-icons/email.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Email Url', 'options_framework_theme'),
        'desc' => __('Enter your email address. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'email_url',
        'std' => 'name@your-email.com',
        'type' => 'text');

    $options[] = array(
        'name' => __('Instagram Icon', 'options_framework_theme'),
        'desc' => __('Upload your Instagram Icon', 'options_framework_theme'),
        'id' => 'instagram_icon',
        'std' => THEME_URI . '/img/social-icons/instagram.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Instagram Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Instagram. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'instagram_url',
        'std' => 'http://angiemakes.com',
        'type' => 'text');

    $options[] = array(
        'name' => __('Facebook Icon', 'options_framework_theme'),
        'desc' => __('Upload your Facebook Icon', 'options_framework_theme'),
        'id' => 'facebook_icon',
        'std' => THEME_URI . '/img/social-icons/facebook.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Facebook Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Facebook. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'facebook_url',
        'std' => 'http://angiemakes.com',
        'type' => 'text');

    $options[] = array(
        'name' => __('Bloglovin Icon', 'options_framework_theme'),
        'desc' => __('Upload your Bloglovin Icon', 'options_framework_theme'),
        'id' => 'bloglovin_icon',
        'std' => THEME_URI . '/img/social-icons/bloglovin.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Bloglovin Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Bloglovin. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'bloglovin_url',
        'std' => 'http://angiemakes.com',
        'type' => 'text');

    $options[] = array(
        'name' => __('Google+ Icon', 'options_framework_theme'),
        'desc' => __('Upload your Google+ Icon', 'options_framework_theme'),
        'id' => 'google_plus_icon',
        'std' => THEME_URI . '/img/social-icons/google-plus.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Google+ Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Google+. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'google_plus_url',
        'std' => 'http://angiemakes.com',
        'type' => 'text');

    $options[] = array(
        'name' => __('Flickr Icon', 'options_framework_theme'),
        'desc' => __('Upload your Flickr Icon', 'options_framework_theme'),
        'id' => 'flickr_icon',
        'std' => THEME_URI . '/img/social-icons/flickr.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Flickr Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Flickr. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'flickr_url',
        'std' => 'http://angiemakes.com',
        'type' => 'text');

    $options[] = array(
        'name' => __('Custom 1 Icon', 'options_framework_theme'),
        'desc' => __('Upload your Custom 1 Icon', 'options_framework_theme'),
        'id' => 'custom1_icon',
        'std' => THEME_URI . '/img/social-icons/youtube.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Custom 1 Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Custom 1. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'custom1_url',
        'std' => '',
        'type' => 'text');

    $options[] = array(
        'name' => __('Custom 2 Icon', 'options_framework_theme'),
        'desc' => __('Upload your Custom 2 Icon', 'options_framework_theme'),
        'id' => 'custom2_icon',
        'std' => THEME_URI . '/img/social-icons/etsy.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Custom 2 Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Custom 2. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'custom2_url',
        'std' => '',
        'type' => 'text');

    $options[] = array(
        'name' => __('Custom 3 Icon', 'options_framework_theme'),
        'desc' => __('Upload your Custom 3 Icon', 'options_framework_theme'),
        'id' => 'custom3_icon',
        'std' => THEME_URI . '/img/social-icons/flower.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Custom 3 Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Custom 3. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'custom3_url',
        'std' => '',
        'type' => 'text');

    $options[] = array(
        'name' => __('Custom 4 Icon', 'options_framework_theme'),
        'desc' => __('Upload your Custom 4 Icon', 'options_framework_theme'),
        'id' => 'custom4_icon',
        'std' => THEME_URI . '/img/social-icons/shopping-cart.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Custom 4 Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Custom 4. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'custom4_url',
        'std' => '',
        'type' => 'text');

    $options[] = array(
        'name' => __('Custom 5 Icon', 'options_framework_theme'),
        'desc' => __('Upload your Custom 5 Icon', 'options_framework_theme'),
        'id' => 'custom5_icon',
        'std' => THEME_URI . '/img/social-icons/blogger.png',
        'type' => 'upload');

    $options[] = array(
        'name' => __('Custom 5 Url', 'options_framework_theme'),
        'desc' => __('Enter your url for Custom 5. Leave blank if you do not want the icon to appear.', 'options_framework_theme'),
        'id' => 'custom5_url',
        'std' => '',
        'type' => 'text');

    /* CSS */
    $options[] = array(
        'name' => __('CSS', 'options_framework_theme'),
        'type' => 'heading');

    $options[] = array(
        'name' => __('Custom CSS Stylesheet', 'options_framework_theme'),
        'id' => 'custom_css',
        'std' => '',
        'type' => 'code');

    return $options;
}

/*function optionsframework_compile() {
    try {
        $less = new lessc;
        $less->setVariables(array(
            "bgBorderColor" => "#000000",
        ));
        $less->setFormatter("compressed");
        $less->compileFile(BOOTSTRAP_LESS, BOOTSTRAP_CSS);
    } catch (exception $e) {
        echo "fatal error: " . $e->getMessage();
    }
}*/

//add_action( 'optionsframework_after_validate', 'optionsframework_compile' );

/*
 * This is an example of how to add custom scripts to the options panel.
 * This example shows/hides an option when a checkbox is clicked.
 */

add_action('optionsframework_custom_scripts', 'optionsframework_custom_scripts');

function optionsframework_custom_scripts() { ?>

<script type="text/javascript">
jQuery(document).ready(function($) {

    $('#example_showhidden').click(function() {
        $('#section-example_text_hidden').fadeToggle(400);
    });

    if ($('#example_showhidden:checked').val() !== undefined) {
        $('#section-example_text_hidden').show();
    }

});
</script>

<?php
}

?>
